@@ -8,10 +8,11 @@
  */
 
 #include "ParseFrame.h"
+
 #include "uncrustify.h"
 #include "uncrustify_types.h"
-#include <string>
 #include <stdexcept>
+#include <string>
 
 
 using std::string;
@@ -95,6 +96,7 @@ ContainerType &ParseFrame::prev(size_t idx)
       throw invalid_argument(string(__FILE__) + ":" + to_string(__LINE__)
                              + " idx can't be zero");
    }
+
    if (idx >= pse.size())
    {
       LOG_FMT(LINDPSE, "%s(%d): idx is %zu, size is %zu\n",
@@ -143,35 +145,56 @@ const ContainerType &ParseFrame::top() const
 }
 
 
-void ParseFrame::push(chunk_t &pc, brace_stage_e stage)
+void ParseFrame::push(std::nullptr_t, brace_stage_e stage)
+{
+   static chunk_t dummy;
+
+   push(&dummy, __func__, __LINE__, stage);
+   top().pc = nullptr;
+}
+
+
+void ParseFrame::push(chunk_t *pc, const char *func, int line, brace_stage_e stage)
 {
    LOG_FUNC_ENTRY();
 
    ContainerType new_entry = {};
-   new_entry.type      = pc.type;
-   new_entry.level     = pc.level;
-   new_entry.open_line = pc.orig_line;
-   new_entry.pc        = &pc;
+
+   new_entry.type      = pc->type;
+   new_entry.level     = pc->level;
+   new_entry.open_line = pc->orig_line;
+   new_entry.open_colu = pc->orig_col;
+   new_entry.pc        = pc;
 
    new_entry.indent_tab  = top().indent_tab;
    new_entry.indent_cont = top().indent_cont;
    new_entry.stage       = stage;
 
-   new_entry.in_preproc = (pc.flags & PCF_IN_PREPROC);
+   new_entry.in_preproc = pc->flags.test(PCF_IN_PREPROC);
    new_entry.non_vardef = false;
    new_entry.ip         = top().ip;
 
    pse.push_back(new_entry);
 
-   LOG_FMT(LINDPSE, "ParseFrame::%s(%d): orig_line is %zu, orig_col is %zu, type is %s, brace_level is %zu, "
-           "level is %zu, pse_tos: %zu -> %zu\n",
-           __func__, __LINE__, pc.orig_line, pc.orig_col,
-           get_token_name(pc.type), pc.brace_level, pc.level, (pse.size() - 2),
-           (pse.size() - 1));
+// un comment the line below to get the address of the pse
+// #define DEBUG_PUSH_POP
+#ifdef DEBUG_PUSH_POP
+   LOG_FMT(LINDPSE, "ParseFrame::push(%s:%d) Add is %zu: orig_line is %zu, orig_col is %zu, type is %s, "
+           "brace_level is %zu, level is %zu, pse_tos: %zu -> %zu\n",
+           func, line, (size_t)this, pc->orig_line, pc->orig_col,
+           get_token_name(pc->type), pc->brace_level, pc->level,
+           (pse.size() - 2), (pse.size() - 1));
+#else /* DEBUG_PUSH_POP */
+   LOG_FMT(LINDPSE, "ParseFrame::push(%s:%d): orig_line is %zu, orig_col is %zu, type is %s, "
+           "brace_level is %zu, level is %zu, pse_tos: %zu -> %zu\n",
+           func, line, pc->orig_line, pc->orig_col,
+           get_token_name(pc->type), pc->brace_level, pc->level,
+           (pse.size() - 2), (pse.size() - 1));
+#endif /* DEBUG_PUSH_POP */
 }
 
 
-void ParseFrame::pop()
+void ParseFrame::pop(const char *func, int line)
 {
    LOG_FUNC_ENTRY();
 
@@ -182,11 +205,19 @@ void ParseFrame::pop()
 //                        + "the stack index is already zero");
 //   }
 
-   LOG_FMT(LINDPSE, "ParseFrame::%s(%d): cpd.pp_level is %d, pse type is %s, "
-           "pse open_line is %zu, pse level is %zu, pse_tos: %zu -> %zu\n",
-           __func__, __LINE__, cpd.pp_level, get_token_name(pse.back().type),
-           pse.back().open_line, pse.back().level, (pse.size() - 1),
-           (pse.size() - 2));
+#ifdef DEBUG_PUSH_POP
+   LOG_FMT(LINDPSE, "ParseFrame::pop (%s:%d) Add is %zu: open_line is %zu, clos_col is %zu, type is %s, "
+           "cpd.level   is %d, level is %zu, pse_tos: %zu -> %zu\n",
+           func, line, (size_t)this, pse.back().open_line, pse.back().open_colu,
+           get_token_name(pse.back().type), cpd.pp_level, pse.back().level,
+           (pse.size() - 1), (pse.size() - 2));
+#else /* DEBUG_PUSH_POP */
+   LOG_FMT(LINDPSE, "ParseFrame::pop (%s:%d): open_line is %zu, clos_col is %zu, type is %s, "
+           "cpd.level   is %d, level is %zu, pse_tos: %zu -> %zu\n",
+           func, line, pse.back().open_line, pse.back().open_colu,
+           get_token_name(pse.back().type), cpd.pp_level, pse.back().level,
+           (pse.size() - 1), (pse.size() - 2));
+#endif /* DEBUG_PUSH_POP */
 
    last_poped = *std::prev(std::end(pse));
 
