@@ -12,6 +12,7 @@
 
 #include "align_asm_colon.h"
 #include "align_assign.h"
+#include "align_eigen_comma_init.h"
 #include "align_func_params.h"
 #include "align_func_proto.h"
 #include "align_init_brace.h"
@@ -129,6 +130,12 @@ void align_all(void)
    {
       align_left_shift();
    }
+   log_rule_B("align_eigen_comma_init");
+
+   if (options::align_eigen_comma_init())
+   {
+      align_eigen_comma_init();
+   }
    log_rule_B("align_oc_msg_colon_span");
 
    if (options::align_oc_msg_colon_span() > 0)
@@ -149,6 +156,7 @@ void align_all(void)
    // Align assignments
    log_rule_B("align_enum_equ_span");
    log_rule_B("align_assign_span");
+   log_rule_B("align_assign_thresh");
 
    if (  (options::align_enum_equ_span() > 0)
       || (options::align_assign_span() > 0))
