@@ -11,9 +11,7 @@
 #include "align_stack.h"
 #include "log_rules.h"
 
-#ifdef WIN32
 #include <algorithm>                           // to get max
-#endif /* ifdef WIN32 */
 
 using namespace uncrustify;
 
@@ -23,7 +21,8 @@ chunk_t *align_func_param(chunk_t *start)
    LOG_FUNC_ENTRY();
 
    LOG_FMT(LAS, "AlignStack::%s(%d): Candidate is '%s': orig_line is %zu, column is %zu, type is %s, level is %zu\n",
-           __func__, __LINE__, start->text(), start->orig_line, start->column, get_token_name(start->type), start->level);
+           __func__, __LINE__, start->text(), start->orig_line, start->column,
+           get_token_name(start->type), start->level);
    // Defaults, if the align_func_params = true
    size_t myspan   = 2;
    size_t mythresh = 0;
@@ -40,15 +39,15 @@ chunk_t *align_func_param(chunk_t *start)
       log_rule_B("align_func_params_gap");
       mygap = options::align_func_params_gap();
    }
-#define HOW_MANY_AS    8
-   size_t     max_level_is = 0;
-   AlignStack many_as[HOW_MANY_AS + 1];
-   // NOTE: many_as[0] is not used
+   const size_t HOW_MANY_AS = 16;                         // Issue #2921
+   AlignStack   many_as[HOW_MANY_AS + 1];
+
+   size_t       max_level_is = 0;
 
    log_rule_B("align_var_def_star_style");
    log_rule_B("align_var_def_amp_style");
 
-   for (size_t idx = 1; idx <= HOW_MANY_AS; idx++)
+   for (size_t idx = 0; idx <= HOW_MANY_AS; idx++)
    {
       many_as[idx].Start(myspan, mythresh);
       many_as[idx].m_gap        = mygap;
@@ -64,9 +63,8 @@ chunk_t *align_func_param(chunk_t *start)
    {
       chunk_count++;
       LOG_FMT(LFLPAREN, "%s(%d): orig_line is %zu, orig_col is %zu, text() is '%s', type is %s\n",
-              __func__, __LINE__, pc->orig_line, pc->orig_col, pc->text(), get_token_name(pc->type));
-      //LOG_FMT(LFLPAREN, "   pc->flags: ");
-      //log_pcf_flags(LFLPAREN, pc->flags);
+              __func__, __LINE__, pc->orig_line, pc->orig_col, pc->text(),
+              get_token_name(pc->type));
 
       if (chunk_is_token(pc, CT_FUNC_VAR))                    // Issue #2278
       {
@@ -102,12 +100,6 @@ chunk_t *align_func_param(chunk_t *start)
       }
       else if (pc->level <= start->level)
       {
-         // for debuging purpose only
-         //for (size_t idx = 1; idx <= max_level_is; idx++)
-         //{
-         //   many_as[idx].Debug();
-         //}
-
          break;
       }
       else if (pc->flags.test(PCF_VAR_DEF))
@@ -118,7 +110,7 @@ chunk_t *align_func_param(chunk_t *start)
             {
                fprintf(stderr, "%s(%d): Not enought memory for Stack\n",
                        __func__, __LINE__);
-               fprintf(stderr, "%s(%d): the current maximum is %d\n",
+               fprintf(stderr, "%s(%d): the current maximum is %zu\n",
                        __func__, __LINE__, HOW_MANY_AS);
                log_flush(true);
                exit(EX_SOFTWARE);
@@ -137,11 +129,21 @@ chunk_t *align_func_param(chunk_t *start)
       }
       else if (chunk_is_token(pc, CT_COMMA))
       {
-         chunk_t *tmp_prev = chunk_get_prev_nc(pc);
-
-         if (!chunk_is_newline(tmp_prev))  // don't count leading commas
+         if (pc->flags.test(PCF_IN_TEMPLATE))            // Issue #2757
          {
-            comma_count++;
+            LOG_FMT(LFLPAREN, "%s(%d): comma is in template\n",
+                    __func__, __LINE__);
+         }
+         else
+         {
+            chunk_t *tmp_prev = chunk_get_prev_nc(pc);
+
+            if (!chunk_is_newline(tmp_prev))  // don't count leading commas
+            {
+               comma_count++;
+               LOG_FMT(LFLPAREN, "%s(%d): comma_count is %zu\n",
+                       __func__, __LINE__, comma_count);
+            }
          }
       }
    }
@@ -165,9 +167,10 @@ void align_func_params(void)
    while ((pc = chunk_get_next(pc)) != nullptr)
    {
       LOG_FMT(LFLPAREN, "%s(%d): orig_line is %zu, orig_col is %zu, text() is '%s', parent_type is %s, parent_type is %s\n",
-              __func__, __LINE__, pc->orig_line, pc->orig_col, pc->text(), get_token_name(pc->type), get_token_name(pc->parent_type));
+              __func__, __LINE__, pc->orig_line, pc->orig_col, pc->text(),
+              get_token_name(pc->type), get_token_name(pc->parent_type));
 
-      if (  pc->type != CT_FPAREN_OPEN
+      if (  chunk_is_not_token(pc, CT_FPAREN_OPEN)
          || (  get_chunk_parent_type(pc) != CT_FUNC_PROTO
             && get_chunk_parent_type(pc) != CT_FUNC_DEF
             && get_chunk_parent_type(pc) != CT_FUNC_CLASS_PROTO
