@@ -8,6 +8,7 @@
  */
 
 #include "align_nl_cont.h"
+
 #include "align_add.h"
 #include "ChunkStack.h"
 #include "uncrustify.h"
@@ -24,9 +25,9 @@ chunk_t *align_nl_cont(chunk_t *start)
    ChunkStack cs;
    size_t     max_col = 0;
    chunk_t    *pc     = start;
-   while (  pc != nullptr
-         && pc->type != CT_NEWLINE
-         && pc->type != CT_COMMENT_MULTI)
+
+   while (  chunk_is_not_token(pc, CT_NEWLINE)
+         && chunk_is_not_token(pc, CT_COMMENT_MULTI))
    {
       if (chunk_is_token(pc, CT_NL_CONT))
       {
@@ -34,15 +35,14 @@ chunk_t *align_nl_cont(chunk_t *start)
       }
       pc = chunk_get_next(pc);
    }
-
    // NL_CONT is always the last thing on a line
    chunk_t *tmp;
+
    while ((tmp = cs.Pop_Back()) != nullptr)
    {
       chunk_flags_set(tmp, PCF_WAS_ALIGNED);
       tmp->column = max_col;
    }
-
    return(pc);
 } // align_nl_cont
 
@@ -51,9 +51,10 @@ void align_backslash_newline(void)
 {
    LOG_FUNC_ENTRY();
    chunk_t *pc = chunk_get_head();
+
    while (pc != nullptr)
    {
-      if (pc->type != CT_NL_CONT)
+      if (chunk_is_not_token(pc, CT_NL_CONT))
       {
          pc = chunk_get_next_type(pc, CT_NL_CONT, -1);
          continue;
