@@ -16,7 +16,9 @@
 #include "prototypes.h"
 #include "space.h"
 #include "uncrustify.h"
-//#include "unc_tools.h"                   // to get stackID and get_A_Number()
+#if defined WITH_STACKID
+#include "unc_tools.h"                   // to get stackID and get_A_Number()
+#endif
 
 #include <limits>
 
@@ -28,11 +30,14 @@ using std::numeric_limits;
 
 void AlignStack::Start(size_t span, int thresh)
 {
-   //stackID = get_A_Number();   // for debugging purpose only
-   //LOG_FMT(LAS, "AlignStack::%s(%d): stackID is %2zu, ", __func__, __LINE__, stackID);
-   LOG_FMT(LAS, "AlignStack::Start(%d): span is %zu, thresh is %d\n", __LINE__, span, thresh);
+#if defined WITH_STACKID
+   stackID = get_A_Number();   // for debugging purpose only
+#endif
+   WITH_STACKID_DEBUG;
 
+   LOG_FMT(LAS, "AlignStack::Start(%d):m_aligned.Reset()\n", __LINE__);
    m_aligned.Reset();
+   LOG_FMT(LAS, "AlignStack::Start(%d):m_skipped.Reset()\n", __LINE__);
    m_skipped.Reset();
 
    if (thresh > 0)
@@ -59,7 +64,7 @@ void AlignStack::Start(size_t span, int thresh)
 
 void AlignStack::ReAddSkipped()
 {
-   //LOG_FMT(LAS, "AlignStack::%s(%d): stackID is %2zu\n", __func__, __LINE__, stackID);
+   WITH_STACKID_DEBUG;
 
    if (m_skipped.Empty())
    {
@@ -67,6 +72,7 @@ void AlignStack::ReAddSkipped()
    }
    // Make a copy of the ChunkStack and clear m_skipped
    m_scratch.Set(m_skipped);
+   LOG_FMT(LAS, "AlignStack::ReAddSkipped(%d):m_skipped.Reset()\n", __LINE__);
    m_skipped.Reset();
 
    // Need to add them in order so that m_nl_seqnum is correct
@@ -83,16 +89,19 @@ void AlignStack::ReAddSkipped()
 
 void AlignStack::Add(chunk_t *start, size_t seqnum)
 {
-   //LOG_FMT(LAS, "AlignStack::%s(%d): stackID is %2zu, for '%s', ", __func__, __LINE__, stackID, start->text());
+   WITH_STACKID_DEBUG;
    LOG_FUNC_ENTRY();
 
    LOG_FMT(LAS, "AlignStack::%s(%d): Candidate is '%s': orig_line is %zu, column is %zu, type is %s, level is %zu\n",
            __func__, __LINE__, start->text(), start->orig_line, start->column, get_token_name(start->type), start->level);
+   LOG_FMT(LAS, "AlignStack::%s(%d): seqnum is %zu\n", __func__, __LINE__, seqnum);
 
    // Assign a seqnum if needed
    if (seqnum == 0)
    {
+      LOG_FMT(LAS, "AlignStack::%s(%d): m_seqnum is %zu\n", __func__, __LINE__, m_seqnum);
       seqnum = m_seqnum;
+      LOG_FMT(LAS, "AlignStack::%s(%d): seqnum is %zu\n", __func__, __LINE__, seqnum);
    }
    m_last_added = 0;
 
@@ -154,6 +163,7 @@ void AlignStack::Add(chunk_t *start, size_t seqnum)
     *
     * If align_on_tabstop=true, then SS_DANGLE is changed to SS_INCLUDE.
     */
+   log_rule_B("align_on_tabstop");
 
    if (options::align_on_tabstop() && m_star_style == SS_DANGLE)
    {
@@ -215,6 +225,7 @@ void AlignStack::Add(chunk_t *start, size_t seqnum)
          tmp_prev = chunk_get_prev(ali);
       }
    }
+   log_rule_B("align_keep_extra_space");
 
    // Tighten down the spacing between ref and start
    if (!options::align_keep_extra_space())
@@ -345,21 +356,22 @@ void AlignStack::Add(chunk_t *start, size_t seqnum)
               seqnum, m_nl_seqnum, m_seqnum,
               start->orig_line, start->column, m_max_col, m_thresh);
    }
-   //LOG_FMT(LAS, "AlignStack::%s(%d): stackID is %2zu, ", __func__, __LINE__, stackID);
+   WITH_STACKID_DEBUG;
 } // AlignStack::Add
 
 
 void AlignStack::NewLines(size_t cnt)
 {
-   //LOG_FMT(LAS, "AlignStack::%s(%d): stackID is %2zu\n", __func__, __LINE__, stackID);
+   WITH_STACKID_DEBUG;
 
    if (m_aligned.Empty())
    {
       LOG_FMT(LAS, "AlignStack::Newlines(%d): nothing to do, is empty\n", __LINE__);
       return;
    }
+   LOG_FMT(LAS, "AlignStack::Newlines(%d): cnt is %zu\n", __LINE__, cnt);
    m_seqnum += cnt;
-   LOG_FMT(LAS, "AlignStack::Newlines(%d): m_seqnum is %zu, m_nl_seqnum is %zu, m_span is %zu, \n",
+   LOG_FMT(LAS, "AlignStack::Newlines(%d): m_seqnum is %zu, m_nl_seqnum is %zu, m_span is %zu\n",
            __LINE__, m_seqnum, m_nl_seqnum, m_span);
 
    if (m_seqnum > (m_nl_seqnum + m_span))
@@ -372,7 +384,8 @@ void AlignStack::NewLines(size_t cnt)
 
 void AlignStack::Flush()
 {
-   //LOG_FMT(LAS, "AlignStack::%s(%d): stackID is %2zu\n", __func__, __LINE__, stackID);
+   WITH_STACKID_DEBUG;
+
    LOG_FMT(LAS, "AlignStack::%s(%d): Len() is %zu\n",
            __func__, __LINE__, Len());
 
@@ -400,6 +413,10 @@ void AlignStack::Flush()
    m_last_added = 0;
    m_max_col    = 0;
 
+   WITH_STACKID_DEBUG;
+   LOG_FMT(LAS, "AlignStack::%s(%d): Debug the stack, Len is %zu\n",
+           __func__, __LINE__, Len());
+
    for (size_t idx = 0; idx < Len(); idx++)
    {
       chunk_t *pc = m_aligned.Get(idx)->m_pc;
@@ -435,18 +452,21 @@ void AlignStack::Flush()
       if (m_right_align)
       {
          // Adjust the width for signed numbers
-         size_t start_len = pc->align.start->len();
-
-         if (pc->align.start->type == CT_NEG)
+         if (pc->align.start != nullptr)
          {
-            chunk_t *next = chunk_get_next(pc->align.start);
+            size_t start_len = pc->align.start->len();
 
-            if (chunk_is_token(next, CT_NUMBER))
+            if (pc->align.start->type == CT_NEG)
             {
-               start_len += next->len();
+               chunk_t *next = chunk_get_next(pc->align.start);
+
+               if (chunk_is_token(next, CT_NUMBER))
+               {
+                  start_len += next->len();
+               }
             }
+            col_adj += start_len;
          }
-         col_adj += start_len;
       }
       pc->align.col_adj = col_adj;
 
@@ -460,6 +480,8 @@ void AlignStack::Flush()
       }
    }
 
+   log_rule_B("align_on_tabstop");
+
    if (  options::align_on_tabstop()
       && Len() > 1)
    {
@@ -473,8 +495,8 @@ void AlignStack::Flush()
    for (size_t idx = 0; idx < Len(); idx++)
    {
       ce = m_aligned.Get(idx);
-      LOG_FMT(LAS, "AlignStack::%s(%d): idx is %zu, ce->m_pc->text() is '%s', ce->m_pc->align.col_adj is %d\n",
-              __func__, __LINE__, idx, ce->m_pc->text(), ce->m_pc->align.col_adj);
+      LOG_FMT(LAS, "AlignStack::%s(%d): idx is %zu, ce->m_pc->text() is '%s', orig_line is %zu, orig_col is %zu, align.col_adj is %d\n",
+              __func__, __LINE__, idx, ce->m_pc->text(), ce->m_pc->orig_line, ce->m_pc->orig_col, ce->m_pc->align.col_adj);
    }
 
    for (size_t idx = 0; idx < Len(); idx++)
@@ -507,8 +529,8 @@ void AlignStack::Flush()
       pc->align.next = m_aligned.GetChunk(idx + 1);
 
       // Indent the token, taking col_adj into account
-      LOG_FMT(LAS, "AlignStack::%s(%d): orig_line is %zu, text() '%s', to col %zu (adj is %d)\n",
-              __func__, __LINE__, pc->orig_line, pc->text(), tmp_col, pc->align.col_adj);
+      LOG_FMT(LAS, "AlignStack::%s(%d): orig_line is %zu, orig_col is %zu, text() '%s', set to col %zu (adj is %d)\n",
+              __func__, __LINE__, pc->orig_line, pc->orig_col, pc->text(), tmp_col, pc->align.col_adj);
       align_to_column(pc, tmp_col);
    }
 
@@ -517,6 +539,7 @@ void AlignStack::Flush()
    if (ce != nullptr)
    {
       last_seqnum = ce->m_seqnum;
+      LOG_FMT(LAS, "AlignStack::Flush(%d):m_aligned.Reset()\n", __LINE__);
       m_aligned.Reset();
    }
    m_min_col = numeric_limits<size_t>::max(); // use unrealistic high numbers
@@ -547,22 +570,26 @@ void AlignStack::Flush()
 
 void AlignStack::Reset()
 {
-   //LOG_FMT(LAS, "AlignStack::%s(%d): stackID is %2zu\n", __func__, __LINE__, stackID);
+   WITH_STACKID_DEBUG;
+   LOG_FMT(LAS, "AlignStack::Reset(%d):m_aligned.Reset()\n", __LINE__);
    m_aligned.Reset();
+   LOG_FMT(LAS, "AlignStack::Reset(%d):m_skipped.Reset()\n", __LINE__);
    m_skipped.Reset();
 }
 
 
 void AlignStack::End()
 {
-   //LOG_FMT(LAS, "AlignStack::%s(%d): stackID is %2zu\n", __func__, __LINE__, stackID);
+   WITH_STACKID_DEBUG;
 
    if (!m_aligned.Empty())
    {
       LOG_FMT(LAS, "AlignStack::End(%d):\n", __LINE__);
       Flush();
    }
+   LOG_FMT(LAS, "AlignStack::End(%d):m_aligned.Reset()\n", __LINE__);
    m_aligned.Reset();
+   LOG_FMT(LAS, "AlignStack::End(%d):m_skipped.Reset()\n", __LINE__);
    m_skipped.Reset();
 }
 
@@ -575,19 +602,29 @@ size_t AlignStack::Len()
 
 void AlignStack::Debug()
 {
-   for (size_t idx = 0; idx < Len(); idx++)
-   {
-      chunk_t *pc = m_aligned.Get(idx)->m_pc;
+   WITH_STACKID_DEBUG;
 
-      if (chunk_is_token(pc, CT_PTR_TYPE))
+   size_t length = Len();
+
+   if (length > 0)
+   {
+      LOG_FMT(LAS, "AlignStack::%s(%d): Debug the stack, Len is %zu\n",
+              __func__, __LINE__, Len());
+
+      for (size_t idx = 0; idx < length; idx++)
       {
-         LOG_FMT(LAS, "AlignStack::%s(%d): idx is %zu, [%s][%s]: orig_line is %zu, type is %s, level is %zu\n",
-                 __func__, __LINE__, idx, pc->text(), pc->next->text(), pc->orig_line, get_token_name(pc->type), pc->level);
-      }
-      else
-      {
-         LOG_FMT(LAS, "AlignStack::%s(%d): idx is %zu, [%s]: orig_line is %zu, type is %s, level is %zu\n",
-                 __func__, __LINE__, idx, pc->text(), pc->orig_line, get_token_name(pc->type), pc->level);
+         chunk_t *pc = m_aligned.Get(idx)->m_pc;
+
+         if (chunk_is_token(pc, CT_PTR_TYPE))
+         {
+            LOG_FMT(LAS, "AlignStack::%s(%d): idx is %zu, [%s][%s]: orig_line is %zu, orig_col is %zu, type is %s, level is %zu, brace_level is %zu\n",
+                    __func__, __LINE__, idx, pc->text(), pc->next->text(), pc->orig_line, pc->orig_col, get_token_name(pc->type), pc->level, pc->brace_level);
+         }
+         else
+         {
+            LOG_FMT(LAS, "AlignStack::%s(%d): idx is %zu, [%s]: orig_line is %zu, orig_col is %zu, type is %s, level is %zu, brace_level is %zu\n",
+                    __func__, __LINE__, idx, pc->text(), pc->orig_line, pc->orig_col, get_token_name(pc->type), pc->level, pc->brace_level);
+         }
       }
    }
 }
