@@ -8,9 +8,11 @@
  */
 
 #include "align_tab_column.h"
-#include "uncrustify_types.h"
+
 #include "chunk_list.h"
+#include "log_rules.h"
 #include "prototypes.h"
+#include "uncrustify_types.h"
 
 using namespace uncrustify;
 
@@ -28,6 +30,8 @@ size_t align_tab_column(size_t col)
    {
       col = 1;
    }
+   log_rule_B("output_tab_size");
+
    if ((col % uncrustify::options::output_tab_size()) != 1)
    {
       col = next_tab_column(col);
