@@ -11,6 +11,7 @@
 
 #include "space.h"
 #include "uncrustify.h"
+#include "uncrustify_limits.h"
 
 
 chunk_t *skip_c99_array(chunk_t *sq_open)
@@ -88,10 +89,12 @@ chunk_t *scan_ib_line(chunk_t *start, bool first_pass)
             cpd.al[cpd.al_cnt].len  = token_width;
             cpd.al_cnt++;
 
-            if (cpd.al_cnt == AL_SIZE)
+            if (cpd.al_cnt == uncrustify::limits::AL_SIZE)
             {
-               fprintf(stderr, "Number of 'entry' to be aligned is too big for the current value %d,\n", AL_SIZE);
-               fprintf(stderr, "at line %zu, column %zu.\n", pc->orig_line, pc->orig_col);
+               fprintf(stderr, "Number of 'entry' to be aligned is too big for the current value %d,\n",
+                       uncrustify::limits::AL_SIZE);
+               fprintf(stderr, "at line %zu, column %zu.\n",
+                       pc->orig_line, pc->orig_col);
                fprintf(stderr, "Please make a report.\n");
                log_flush(true);
                exit(EX_SOFTWARE);
