@@ -8,8 +8,10 @@
  */
 
 #include "align_typedefs.h"
+
 #include "align_stack.h"
 #include "chunk_list.h"
+#include "log_rules.h"
 
 using namespace uncrustify;
 
@@ -19,13 +21,18 @@ void align_typedefs(size_t span)
    LOG_FUNC_ENTRY();
 
    AlignStack as;
+
    as.Start(span);
-   as.m_gap        = options::align_typedef_gap();
+   log_rule_B("align_typedef_gap");
+   as.m_gap = options::align_typedef_gap();
+   log_rule_B("align_typedef_star_style");
    as.m_star_style = static_cast<AlignStack::StarStyle>(options::align_typedef_star_style());
-   as.m_amp_style  = static_cast<AlignStack::StarStyle>(options::align_typedef_amp_style());
+   log_rule_B("align_typedef_amp_style");
+   as.m_amp_style = static_cast<AlignStack::StarStyle>(options::align_typedef_amp_style());
 
    chunk_t *c_typedef = nullptr;
    chunk_t *pc        = chunk_get_head();
+
    while (pc != nullptr)
    {
       if (chunk_is_newline(pc))
@@ -35,7 +42,7 @@ void align_typedefs(size_t span)
       }
       else if (c_typedef != nullptr)
       {
-         if (pc->flags & PCF_ANCHOR)
+         if (pc->flags.test(PCF_ANCHOR))
          {
             as.Add(pc);
             LOG_FMT(LALTD, "%s(%d): typedef @ %zu:%zu, tag '%s' @ %zu:%zu\n",
@@ -51,9 +58,7 @@ void align_typedefs(size_t span)
             c_typedef = pc;
          }
       }
-
       pc = chunk_get_next(pc);
    }
-
    as.End();
 } // align_typedefs
