@@ -46,6 +46,14 @@ using std::stringstream;
  */
 
 
+struct BraceState
+{
+   std::vector<ParseFrame> frames     = {};
+   c_token_t               in_preproc = CT_NONE;
+   int                     pp_level   = 0;
+   bool                    consumed   = false;
+};
+
 /**
  * Called when a statement was just closed and the pse_tos was just
  * decremented.
@@ -56,10 +64,10 @@ using std::stringstream;
  * @retval true   done with this chunk
  * @retval false  keep processing
  */
-static bool close_statement(ParseFrame &frm, chunk_t *pc);
+static bool close_statement(ParseFrame &frm, chunk_t *pc, const BraceState &braceState);
 
 
-static size_t preproc_start(ParseFrame &frm, chunk_t *pc);
+static size_t preproc_start(BraceState &braceState, ParseFrame &frm, chunk_t *pc);
 
 
 static void print_stack(log_sev_t logsev, const char *str, const ParseFrame &frm);
@@ -81,7 +89,7 @@ static chunk_t *insert_vbrace(chunk_t *pc, bool after, const ParseFrame &frm);
 #define insert_vbrace_close_after(pc, frm)    insert_vbrace(pc, true, frm)
 #define insert_vbrace_open_before(pc, frm)    insert_vbrace(pc, false, frm)
 
-static void parse_cleanup(ParseFrame &frm, chunk_t *pc);
+static void parse_cleanup(BraceState &braceState, ParseFrame &frm, chunk_t *pc);
 
 
 /**
@@ -97,7 +105,7 @@ static void parse_cleanup(ParseFrame &frm, chunk_t *pc);
  *
  * @return true - done with this chunk, false - keep processing
  */
-static bool check_complex_statements(ParseFrame &frm, chunk_t *pc);
+static bool check_complex_statements(ParseFrame &frm, chunk_t *pc, const BraceState &braceState);
 
 
 /**
@@ -109,17 +117,17 @@ static bool check_complex_statements(ParseFrame &frm, chunk_t *pc);
  *
  * @return true - done with this chunk, false - keep processing
  */
-static bool handle_complex_close(ParseFrame &frm, chunk_t *pc);
+static bool handle_complex_close(ParseFrame &frm, chunk_t *pc, const BraceState &braceState);
 
 
 //! We're on a 'namespace' skip the word and then set the parent of the braces.
 static void mark_namespace(chunk_t *pns);
 
 
-static size_t preproc_start(ParseFrame &frm, chunk_t *pc)
+static size_t preproc_start(BraceState &braceState, ParseFrame &frm, chunk_t *pc)
 {
    LOG_FUNC_ENTRY();
-   const size_t pp_level = cpd.pp_level;
+   const size_t pp_level = braceState.pp_level;
 
    chunk_t      *next = chunk_get_next_ncnl(pc);
 
@@ -128,15 +136,15 @@ static size_t preproc_start(ParseFrame &frm, chunk_t *pc)
       return(pp_level);
    }
    // Get the type of preprocessor and handle it
-   cpd.in_preproc = next->type;
+   braceState.in_preproc = next->type;
 
    // If we are not in a define, check for #if, #else, #endif, etc
-   if (cpd.in_preproc != CT_PP_DEFINE)
+   if (braceState.in_preproc != CT_PP_DEFINE)
    {
-      return(fl_check(frm, pc));
+      return(fl_check(braceState.frames, frm, braceState.pp_level, pc));
    }
    // else push the frame stack
-   fl_push(frm);
+   fl_push(braceState.frames, frm);
 
    // a preproc body starts a new, blank frame
    frm             = {};
@@ -184,30 +192,26 @@ void brace_cleanup(void)
 {
    LOG_FUNC_ENTRY();
 
-   cpd.unc_stage = unc_stage_e::BRACE_CLEANUP;
-   cpd.frames.clear();
-   cpd.in_preproc = CT_NONE;
-   cpd.pp_level   = 0;
-
+   BraceState braceState;
    ParseFrame frm{};
    chunk_t    *pc = chunk_get_head();
 
    while (pc != nullptr)
    {
       // Check for leaving a #define body
-      if (cpd.in_preproc != CT_NONE && !pc->flags.test(PCF_IN_PREPROC))
+      if (braceState.in_preproc != CT_NONE && !pc->flags.test(PCF_IN_PREPROC))
       {
-         if (cpd.in_preproc == CT_PP_DEFINE)
+         if (braceState.in_preproc == CT_PP_DEFINE)
          {
             // out of the #define body, restore the frame
-            fl_pop(frm);
+            fl_pop(braceState.frames, frm);
          }
-         cpd.in_preproc = CT_NONE;
+         braceState.in_preproc = CT_NONE;
       }
       // Check for a preprocessor start
       const size_t pp_level = (chunk_is_token(pc, CT_PREPROC))
-                              ? preproc_start(frm, pc)
-                              : cpd.pp_level;
+                              ? preproc_start(braceState, frm, pc)
+                              : braceState.pp_level;
 
       // Do before assigning stuff from the frame
       if (  language_is_set(LANG_PAWN)
@@ -240,10 +244,10 @@ void brace_cleanup(void)
          && !chunk_is_newline(pc)
          && !chunk_is_token(pc, CT_ATTRIBUTE)
          && !chunk_is_token(pc, CT_IGNORED)            // Issue #2279
-         && (cpd.in_preproc == CT_PP_DEFINE || cpd.in_preproc == CT_NONE))
+         && (braceState.in_preproc == CT_PP_DEFINE || braceState.in_preproc == CT_NONE))
       {
-         cpd.consumed = false;
-         parse_cleanup(frm, pc);
+         braceState.consumed = false;
+         parse_cleanup(braceState, frm, pc);
          print_stack(LBCSAFTER, (chunk_is_token(pc, CT_VBRACE_CLOSE)) ? "Virt-}" : pc->str.c_str(), frm);
       }
       pc = chunk_get_next(pc);
@@ -268,7 +272,8 @@ static bool maybe_while_of_do(chunk_t *pc)
       prev = chunk_get_prev_ncnl(prev);
    }
 
-   if (  (chunk_is_token(prev, CT_VBRACE_CLOSE) || chunk_is_token(prev, CT_BRACE_CLOSE))
+   if (  (  chunk_is_token(prev, CT_VBRACE_CLOSE)
+         || chunk_is_token(prev, CT_BRACE_CLOSE))
       && get_chunk_parent_type(prev) == CT_DO)
    {
       return(true);
@@ -331,12 +336,12 @@ static bool maybe_while_of_do(chunk_t *pc)
  * When a #define is entered, the current frame is pushed and cleared.
  * When a #define is exited, the frame is popped.
  */
-static void parse_cleanup(ParseFrame &frm, chunk_t *pc)
+static void parse_cleanup(BraceState &braceState, ParseFrame &frm, chunk_t *pc)
 {
    LOG_FUNC_ENTRY();
 
-   LOG_FMT(LTOK, "%s(%d): orig_line is %zu, type is %s, tos is %zu, TOS.type is %s, TOS.stage is %s, ",
-           __func__, __LINE__, pc->orig_line, get_token_name(pc->type),
+   LOG_FMT(LTOK, "%s(%d): orig_line is %zu, orig_col is %zu, type is %s, tos is %zu, TOS.type is %s, TOS.stage is %s, ",
+           __func__, __LINE__, pc->orig_line, pc->orig_col, get_token_name(pc->type),
            frm.size() - 1, get_token_name(frm.top().type),
            get_brace_stage_name(frm.top().stage));
    log_pcf_flags(LTOK, pc->flags);
@@ -349,8 +354,8 @@ static void parse_cleanup(ParseFrame &frm, chunk_t *pc)
 
    if (  (frm.stmt_count == 0 || frm.expr_count == 0)
       && !chunk_is_semicolon(pc)
-      && pc->type != CT_BRACE_CLOSE
-      && pc->type != CT_VBRACE_CLOSE
+      && chunk_is_not_token(pc, CT_BRACE_CLOSE)
+      && chunk_is_not_token(pc, CT_VBRACE_CLOSE)
       && !chunk_is_str(pc, ")", 1)
       && !chunk_is_str(pc, "]", 1))
    {
@@ -391,7 +396,7 @@ static void parse_cleanup(ParseFrame &frm, chunk_t *pc)
    // Check the progression of complex statements
    if (  frm.top().stage != brace_stage_e::NONE
       && !chunk_is_token(pc, CT_AUTORELEASEPOOL)
-      && check_complex_statements(frm, pc))
+      && check_complex_statements(frm, pc, braceState))
    {
       return;
    }
@@ -406,13 +411,18 @@ static void parse_cleanup(ParseFrame &frm, chunk_t *pc)
    {
       if (chunk_is_semicolon(pc))
       {
-         cpd.consumed = true;
-         close_statement(frm, pc);
+         braceState.consumed = true;
+         close_statement(frm, pc, braceState);
       }
       else if (  language_is_set(LANG_PAWN)
               && chunk_is_token(pc, CT_BRACE_CLOSE))
       {
-         close_statement(frm, pc);
+         close_statement(frm, pc, braceState);
+      }
+      else if (  language_is_set(LANG_D)
+              && chunk_is_token(pc, CT_BRACE_CLOSE))
+      {
+         close_statement(frm, pc, braceState);
       }
    }
 
@@ -440,7 +450,7 @@ static void parse_cleanup(ParseFrame &frm, chunk_t *pc)
       }
 
       // Make sure the open / close match
-      if (pc->type != (frm.top().type + 1))
+      if (chunk_is_not_token(pc, (c_token_t)(frm.top().type + 1)))
       {
          LOG_FMT(LWARN, "%s(%d): pc->orig_line is %zu, orig_col is %zu, text() is '%s', type is %s\n",
                  __func__, __LINE__, pc->orig_line, pc->orig_col, pc->text(), get_token_name(pc->type));
@@ -456,11 +466,12 @@ static void parse_cleanup(ParseFrame &frm, chunk_t *pc)
                     frm.top().pc->orig_line);
             print_stack(LBCSPOP, "=Error  ", frm);
             cpd.error_count++;
+            exit(EXIT_FAILURE);
          }
       }
       else
       {
-         cpd.consumed = true;
+         braceState.consumed = true;
 
          // Copy the parent, update the parenthesis/brace levels
          set_chunk_parent(pc, frm.top().parent);
@@ -484,22 +495,35 @@ static void parse_cleanup(ParseFrame &frm, chunk_t *pc)
          frm.pop(__func__, __LINE__);
          print_stack(LBCSPOP, "-Close  ", frm);
 
+         if (  frm.top().stage == brace_stage_e::NONE
+            && (  chunk_is_token(pc, CT_VBRACE_CLOSE)
+               || chunk_is_token(pc, CT_BRACE_CLOSE)
+               || chunk_is_token(pc, CT_SEMICOLON))
+            && chunk_is_token(frm.top().pc, CT_VBRACE_OPEN))
+         {
+            // frames for functions are not created as they are for an if
+            // this here is a hackish solution to close a vbrace of a block that
+            // contains the function
+            frm.push(nullptr); // <- dummy frame for the function
+            frm.top().stage = brace_stage_e::BRACE2;
+         }
+
          // See if we are in a complex statement
          if (frm.top().stage != brace_stage_e::NONE)
          {
-            handle_complex_close(frm, pc);
+            handle_complex_close(frm, pc, braceState);
          }
       }
    }
 
    /*
     * In this state, we expect a semicolon, but we'll also hit the closing
-    * sparen, so we need to check cpd.consumed to see if the close sparen was
-    * aleady handled.
+    * sparen, so we need to check braceState.consumed to see if the close sparen
+    * was aleady handled.
     */
    if (frm.top().stage == brace_stage_e::WOD_SEMI)
    {
-      if (cpd.consumed)
+      if (braceState.consumed)
       {
          /*
           * If consumed, then we are on the close sparen.
@@ -510,9 +534,8 @@ static void parse_cleanup(ParseFrame &frm, chunk_t *pc)
          {
             chunk_t *tmp = chunk_get_next_ncnl(pc);
 
-            if (  tmp != nullptr
-               && tmp->type != CT_SEMICOLON
-               && tmp->type != CT_VSEMICOLON)
+            if (  chunk_is_not_token(tmp, CT_SEMICOLON)
+               && chunk_is_not_token(tmp, CT_VSEMICOLON))
             {
                pawn_add_vsemi_after(pc);
             }
@@ -521,9 +544,10 @@ static void parse_cleanup(ParseFrame &frm, chunk_t *pc)
       else
       {
          // Complain if this ISN'T a semicolon, but close out WHILE_OF_DO anyway
-         if (chunk_is_token(pc, CT_SEMICOLON) || chunk_is_token(pc, CT_VSEMICOLON))
+         if (  chunk_is_token(pc, CT_SEMICOLON)
+            || chunk_is_token(pc, CT_VSEMICOLON))
          {
-            cpd.consumed = true;
+            braceState.consumed = true;
             set_chunk_parent(pc, CT_WHILE_OF_DO);
          }
          else
@@ -533,7 +557,7 @@ static void parse_cleanup(ParseFrame &frm, chunk_t *pc)
                     get_token_name(pc->type));
             cpd.error_count++;
          }
-         handle_complex_close(frm, pc);
+         handle_complex_close(frm, pc, braceState);
       }
    }
    // Get the parent type for brace and parenthesis open
@@ -554,6 +578,7 @@ static void parse_cleanup(ParseFrame &frm, chunk_t *pc)
          {
             // Set the parent for parenthesis and change parenthesis type
             if (  chunk_is_token(prev, CT_IF)
+               || chunk_is_token(prev, CT_CONSTEXPR)
                || chunk_is_token(prev, CT_ELSEIF)
                || chunk_is_token(prev, CT_WHILE)
                || chunk_is_token(prev, CT_DO)
@@ -576,7 +601,8 @@ static void parse_cleanup(ParseFrame &frm, chunk_t *pc)
                parent = CT_FUNCTION;
             }
             // NS_ENUM and NS_OPTIONS are followed by a (type, name) pair
-            else if (chunk_is_token(prev, CT_ENUM) && language_is_set(LANG_OC))
+            else if (  chunk_is_token(prev, CT_ENUM)
+                    && language_is_set(LANG_OC))
             {
                // Treat both as CT_ENUM since the syntax is identical
                set_chunk_type(pc, CT_FPAREN_OPEN);
@@ -595,11 +621,13 @@ static void parse_cleanup(ParseFrame &frm, chunk_t *pc)
             {
                parent = frm.top().type;
             }
-            else if (chunk_is_token(prev, CT_ASSIGN) && (prev->str[0] == '='))
+            else if (  chunk_is_token(prev, CT_ASSIGN)
+                    && (prev->str[0] == '='))
             {
                parent = CT_ASSIGN;
             }
-            else if (chunk_is_token(prev, CT_RETURN) && language_is_set(LANG_CPP))
+            else if (  chunk_is_token(prev, CT_RETURN)
+                    && language_is_set(LANG_CPP))
             {
                parent = CT_RETURN;
             }
@@ -744,7 +772,8 @@ static void parse_cleanup(ParseFrame &frm, chunk_t *pc)
    {
       brace_stage_e bs = brace_stage_e::PAREN1;
 
-      if (chunk_is_token(pc, CT_WHILE) && maybe_while_of_do(pc))
+      if (  chunk_is_token(pc, CT_WHILE)
+         && maybe_while_of_do(pc))
       {
          set_chunk_type(pc, CT_WHILE_OF_DO);
          bs = brace_stage_e::WOD_PAREN;
@@ -770,10 +799,12 @@ static void parse_cleanup(ParseFrame &frm, chunk_t *pc)
     *  - after '(' that has a parent type of CT_FOR
     */
    if (  chunk_is_token(pc, CT_SQUARE_OPEN)
-      || (chunk_is_token(pc, CT_BRACE_OPEN) && get_chunk_parent_type(pc) != CT_ASSIGN)
+      || (  chunk_is_token(pc, CT_BRACE_OPEN)
+         && get_chunk_parent_type(pc) != CT_ASSIGN)
       || chunk_is_token(pc, CT_BRACE_CLOSE)
       || chunk_is_token(pc, CT_VBRACE_CLOSE)
-      || (chunk_is_token(pc, CT_SPAREN_OPEN) && get_chunk_parent_type(pc) == CT_FOR)
+      || (  chunk_is_token(pc, CT_SPAREN_OPEN)
+         && get_chunk_parent_type(pc) == CT_FOR)
       || chunk_is_token(pc, CT_COLON)
       || chunk_is_token(pc, CT_OC_END)
       || (  chunk_is_semicolon(pc)
@@ -794,11 +825,12 @@ static void parse_cleanup(ParseFrame &frm, chunk_t *pc)
    chunk_t *tmp = chunk_get_next_ncnl(pc);
 
    if (  chunk_is_token(pc, CT_ARITH)
+      || chunk_is_token(pc, CT_SHIFT)
       || chunk_is_token(pc, CT_ASSIGN)
       || chunk_is_token(pc, CT_CASE)
       || chunk_is_token(pc, CT_COMPARE)
       || (  chunk_is_token(pc, CT_STAR)
-         && tmp != nullptr && tmp->type != CT_STAR)
+         && chunk_is_not_token(tmp, CT_STAR))
       || chunk_is_token(pc, CT_BOOL)
       || chunk_is_token(pc, CT_MINUS)
       || chunk_is_token(pc, CT_PLUS)
@@ -825,8 +857,8 @@ static void parse_cleanup(ParseFrame &frm, chunk_t *pc)
               __func__, __LINE__, pc->orig_line, pc->orig_col, pc->text());
    }
    else if (  chunk_is_token(pc, CT_BRACE_CLOSE)
-           && !cpd.consumed
-           && cpd.in_preproc != CT_PP_DEFINE)
+           && !braceState.consumed
+           && braceState.in_preproc != CT_PP_DEFINE)
    {
       size_t file_pp_level = ifdef_over_whole_file() ? 1 : 0;
 
@@ -849,14 +881,14 @@ static void parse_cleanup(ParseFrame &frm, chunk_t *pc)
 } // parse_cleanup
 
 
-static bool check_complex_statements(ParseFrame &frm, chunk_t *pc)
+static bool check_complex_statements(ParseFrame &frm, chunk_t *pc, const BraceState &braceState)
 {
    LOG_FUNC_ENTRY();
 
    // Turn an optional parenthesis into either a real parenthesis or a brace
    if (frm.top().stage == brace_stage_e::OP_PAREN1)
    {
-      frm.top().stage = (pc->type != CT_PAREN_OPEN)
+      frm.top().stage = (chunk_is_not_token(pc, CT_PAREN_OPEN))
                         ? brace_stage_e::BRACE2
                         : brace_stage_e::PAREN1;
    }
@@ -879,7 +911,7 @@ static bool check_complex_statements(ParseFrame &frm, chunk_t *pc)
       frm.pop(__func__, __LINE__);
       print_stack(LBCSPOP, "-IF-CCS ", frm);
 
-      if (close_statement(frm, pc))
+      if (close_statement(frm, pc, braceState))
       {
          return(true);
       }
@@ -907,7 +939,8 @@ static bool check_complex_statements(ParseFrame &frm, chunk_t *pc)
    // Check for CT_CATCH or CT_FINALLY after CT_TRY or CT_CATCH
    while (frm.top().stage == brace_stage_e::CATCH)
    {
-      if (chunk_is_token(pc, CT_CATCH) || chunk_is_token(pc, CT_FINALLY))
+      if (  chunk_is_token(pc, CT_CATCH)
+         || chunk_is_token(pc, CT_FINALLY))
       {
          // Replace CT_TRY with CT_CATCH or CT_FINALLY on the stack & we are done
          frm.top().type = pc->type;
@@ -933,7 +966,7 @@ static bool check_complex_statements(ParseFrame &frm, chunk_t *pc)
       frm.pop(__func__, __LINE__);
       print_stack(LBCSPOP, "-TRY-CCS ", frm);
 
-      if (close_statement(frm, pc))
+      if (close_statement(frm, pc, braceState))
       {
          return(true);
       }
@@ -991,7 +1024,7 @@ static bool check_complex_statements(ParseFrame &frm, chunk_t *pc)
 
    // Insert a CT_VBRACE_OPEN, if needed
    // but not in a preprocessor
-   if (  pc->type != CT_BRACE_OPEN
+   if (  chunk_is_not_token(pc, CT_BRACE_OPEN)
       && !pc->flags.test(PCF_IN_PREPROC)
       && (  (frm.top().stage == brace_stage_e::BRACE2)
          || (frm.top().stage == brace_stage_e::BRACE_DO)))
@@ -1043,13 +1076,13 @@ static bool check_complex_statements(ParseFrame &frm, chunk_t *pc)
    if (  frm.top().stage == brace_stage_e::PAREN1
       && (  frm.top().type == CT_IF
          || frm.top().type == CT_ELSEIF)
-      && pc->str.equals("constexpr")) // FIXME: Take care of the "constexpr" const string.
+      && chunk_is_token(pc, CT_CONSTEXPR))
    {
       return(false);
    }
 
    // Verify open parenthesis in complex statement
-   if (  pc->type != CT_PAREN_OPEN
+   if (  chunk_is_not_token(pc, CT_PAREN_OPEN)
       && (  (frm.top().stage == brace_stage_e::PAREN1)
          || (frm.top().stage == brace_stage_e::WOD_PAREN)))
    {
@@ -1068,13 +1101,14 @@ static bool check_complex_statements(ParseFrame &frm, chunk_t *pc)
 } // check_complex_statements
 
 
-static bool handle_complex_close(ParseFrame &frm, chunk_t *pc)
+static bool handle_complex_close(ParseFrame &frm, chunk_t *pc, const BraceState &braceState)
 {
    LOG_FUNC_ENTRY();
 
    if (frm.top().stage == brace_stage_e::PAREN1)
    {
-      if (pc->next != nullptr && pc->next->type == CT_WHEN)
+      if (  pc->next != nullptr
+         && pc->next->type == CT_WHEN)
       {
          frm.top().type  = pc->type;
          frm.top().stage = brace_stage_e::CATCH_WHEN;
@@ -1095,14 +1129,15 @@ static bool handle_complex_close(ParseFrame &frm, chunk_t *pc)
          // If the next chunk isn't CT_ELSE, close the statement
          chunk_t *next = chunk_get_next_ncnl(pc);
 
-         if (next != nullptr && next->type != CT_ELSE)
+         if (  next == nullptr
+            || chunk_is_not_token(next, CT_ELSE))
          {
             LOG_FMT(LBCSPOP, "%s(%d): no CT_ELSE, pc->orig_line is %zu, orig_col is %zu, text() is '%s', type is %s\n",
                     __func__, __LINE__, pc->orig_line, pc->orig_col, pc->text(), get_token_name(pc->type));
             frm.pop(__func__, __LINE__);
             print_stack(LBCSPOP, "-IF-HCS ", frm);
 
-            return(close_statement(frm, pc));
+            return(close_statement(frm, pc, braceState));
          }
       }
       else if (  (frm.top().type == CT_TRY)
@@ -1113,16 +1148,15 @@ static bool handle_complex_close(ParseFrame &frm, chunk_t *pc)
          // If the next chunk isn't CT_CATCH or CT_FINALLY, close the statement
          chunk_t *next = chunk_get_next_ncnl(pc);
 
-         if (  next != nullptr
-            && next->type != CT_CATCH
-            && next->type != CT_FINALLY)
+         if (  chunk_is_not_token(next, CT_CATCH)
+            && chunk_is_not_token(next, CT_FINALLY))
          {
             LOG_FMT(LBCSPOP, "%s(%d): pc->orig_line is %zu, orig_col is %zu, text() is '%s', type is %s\n",
                     __func__, __LINE__, pc->orig_line, pc->orig_col, pc->text(), get_token_name(pc->type));
             frm.pop(__func__, __LINE__);
             print_stack(LBCSPOP, "-TRY-HCS ", frm);
 
-            return(close_statement(frm, pc));
+            return(close_statement(frm, pc, braceState));
          }
       }
       else
@@ -1134,7 +1168,7 @@ static bool handle_complex_close(ParseFrame &frm, chunk_t *pc)
          frm.pop(__func__, __LINE__);
          print_stack(LBCSPOP, "-HCC B2 ", frm);
 
-         return(close_statement(frm, pc));
+         return(close_statement(frm, pc, braceState));
       }
    }
    else if (frm.top().stage == brace_stage_e::BRACE_DO)
@@ -1157,7 +1191,7 @@ static bool handle_complex_close(ParseFrame &frm, chunk_t *pc)
       frm.pop(__func__, __LINE__);
       print_stack(LBCSPOP, "-HCC WoDS ", frm);
 
-      return(close_statement(frm, pc));
+      return(close_statement(frm, pc, braceState));
    }
    else
    {
@@ -1192,7 +1226,7 @@ static void mark_namespace(chunk_t *pns)
    {
       set_chunk_parent(pc, CT_NAMESPACE);
 
-      if (pc->type != CT_BRACE_OPEN)
+      if (chunk_is_not_token(pc, CT_BRACE_OPEN))
       {
          if (chunk_is_token(pc, CT_SEMICOLON))
          {
@@ -1305,7 +1339,7 @@ static chunk_t *insert_vbrace(chunk_t *pc, bool after, const ParseFrame &frm)
 } // insert_vbrace
 
 
-bool close_statement(ParseFrame &frm, chunk_t *pc)
+bool close_statement(ParseFrame &frm, chunk_t *pc, const BraceState &braceState)
 {
    LOG_FUNC_ENTRY();
 
@@ -1320,7 +1354,7 @@ bool close_statement(ParseFrame &frm, chunk_t *pc)
            get_token_name(frm.top().type),
            (unsigned int)frm.top().stage);
 
-   if (cpd.consumed)
+   if (braceState.consumed)
    {
       frm.stmt_count = 0;
       frm.expr_count = 0;
@@ -1336,7 +1370,7 @@ bool close_statement(ParseFrame &frm, chunk_t *pc)
    if (frm.top().type == CT_VBRACE_OPEN)
    {
       // If the current token has already been consumed, then add after it
-      if (cpd.consumed)
+      if (braceState.consumed)
       {
          insert_vbrace_close_after(pc, frm);
       }
@@ -1344,11 +1378,12 @@ bool close_statement(ParseFrame &frm, chunk_t *pc)
       {
          // otherwise, add before it and consume the vbrace
          vbc = chunk_get_prev_ncnl(pc);
-         vbc = insert_vbrace_close_after(vbc, frm);
-         set_chunk_parent(vbc, frm.top().parent);
 
          frm.level--;
          frm.brace_level--;
+         vbc = insert_vbrace_close_after(vbc, frm);
+         set_chunk_parent(vbc, frm.top().parent);
+
          LOG_FMT(LBCSPOP, "%s(%d): frm.brace_level decreased to %zu\n",
                  __func__, __LINE__, frm.brace_level);
          log_pcf_flags(LBCSPOP, pc->flags);
@@ -1363,7 +1398,7 @@ bool close_statement(ParseFrame &frm, chunk_t *pc)
          print_stack(LBCSPOP, "-CS VB  ", frm);
 
          // And repeat the close
-         close_statement(frm, pc);
+         close_statement(frm, pc, braceState);
          return(true);
       }
    }
@@ -1371,7 +1406,7 @@ bool close_statement(ParseFrame &frm, chunk_t *pc)
    // See if we are done with a complex statement
    if (frm.top().stage != brace_stage_e::NONE)
    {
-      if (handle_complex_close(frm, vbc))
+      if (handle_complex_close(frm, vbc, braceState))
       {
          return(true);
       }
