@@ -81,11 +81,15 @@ void fix_casts(chunk_t *start)
       LOG_FMT(LCASTS, "%s(%d): pc->text() is '%s', orig_line is %zu, orig_col is %zu, type is %s\n",
               __func__, __LINE__, pc->text(), pc->orig_line, pc->orig_col, get_token_name(pc->type));
 
-      if (chunk_is_token(pc, CT_WORD) || (chunk_is_token(last, CT_ANGLE_CLOSE) && chunk_is_token(pc, CT_DC_MEMBER)))
+      if (  chunk_is_token(pc, CT_WORD)
+         || (  chunk_is_token(last, CT_ANGLE_CLOSE)
+            && chunk_is_token(pc, CT_DC_MEMBER)))
       {
          word_count++;
       }
-      else if (chunk_is_token(pc, CT_DC_MEMBER) || chunk_is_token(pc, CT_MEMBER) || chunk_is_token(pc, CT_PP))
+      else if (  chunk_is_token(pc, CT_DC_MEMBER)
+              || chunk_is_token(pc, CT_MEMBER)
+              || chunk_is_token(pc, CT_PP))
       {
          // might be negativ, such as with:
          // a = val + (CFoo::bar_t)7;
@@ -97,7 +101,7 @@ void fix_casts(chunk_t *start)
    }
 
    if (  pc == nullptr
-      || pc->type != CT_PAREN_CLOSE
+      || chunk_is_not_token(pc, CT_PAREN_CLOSE)
       || chunk_is_token(prev, CT_OC_CLASS))
    {
       LOG_FMT(LCASTS, "%s(%d):  -- not a cast, hit type is %s\n",
@@ -118,7 +122,8 @@ void fix_casts(chunk_t *start)
       || chunk_is_token(last, CT_CARET)
       || chunk_is_token(last, CT_PTR_TYPE)
       || chunk_is_token(last, CT_TYPE)
-      || (chunk_is_token(last, CT_ANGLE_CLOSE) && language_is_set(LANG_OC | LANG_JAVA)))
+      || (  chunk_is_token(last, CT_ANGLE_CLOSE)
+         && language_is_set(LANG_OC | LANG_JAVA)))
    {
       verb = "for sure";
    }
@@ -199,7 +204,8 @@ void fix_casts(chunk_t *start)
       else if (chunk_is_token(pc, CT_MINUS))
       {
          // (UINT8)-1 or (foo)-1 or (FOO)-'a'
-         if (chunk_is_token(after, CT_STRING) || doubtful_cast)
+         if (  chunk_is_token(after, CT_STRING)
+            || doubtful_cast)
          {
             nope = true;
          }
@@ -207,26 +213,27 @@ void fix_casts(chunk_t *start)
       else if (chunk_is_token(pc, CT_PLUS))
       {
          // (UINT8)+1 or (foo)+1
-         if (  (after->type != CT_NUMBER && after->type != CT_NUMBER_FP)
+         if (  (  chunk_is_not_token(after, CT_NUMBER)
+               && chunk_is_not_token(after, CT_NUMBER_FP))
             || doubtful_cast)
          {
             nope = true;
          }
       }
-      else if (  pc->type != CT_NUMBER_FP
-              && pc->type != CT_NUMBER
-              && pc->type != CT_WORD
-              && pc->type != CT_THIS
-              && pc->type != CT_TYPE
-              && pc->type != CT_PAREN_OPEN
-              && pc->type != CT_STRING
-              && pc->type != CT_DECLTYPE
-              && pc->type != CT_SIZEOF
+      else if (  chunk_is_not_token(pc, CT_NUMBER_FP)
+              && chunk_is_not_token(pc, CT_NUMBER)
+              && chunk_is_not_token(pc, CT_WORD)
+              && chunk_is_not_token(pc, CT_THIS)
+              && chunk_is_not_token(pc, CT_TYPE)
+              && chunk_is_not_token(pc, CT_PAREN_OPEN)
+              && chunk_is_not_token(pc, CT_STRING)
+              && chunk_is_not_token(pc, CT_DECLTYPE)
+              && chunk_is_not_token(pc, CT_SIZEOF)
               && get_chunk_parent_type(pc) != CT_SIZEOF
-              && pc->type != CT_FUNC_CALL
-              && pc->type != CT_FUNC_CALL_USER
-              && pc->type != CT_FUNCTION
-              && pc->type != CT_BRACE_OPEN
+              && chunk_is_not_token(pc, CT_FUNC_CALL)
+              && chunk_is_not_token(pc, CT_FUNC_CALL_USER)
+              && chunk_is_not_token(pc, CT_FUNCTION)
+              && chunk_is_not_token(pc, CT_BRACE_OPEN)
               && (!(  chunk_is_token(pc, CT_SQUARE_OPEN)
                    && language_is_set(LANG_OC))))
       {
@@ -319,7 +326,9 @@ void fix_enum_struct_union(chunk_t *pc)
    }
 
    // the next item is either a type, an attribute (TODO), an identifier, a colon or open brace
-   if (chunk_is_token(next, CT_TYPE) || chunk_is_token(next, CT_WORD) || chunk_is_token(next, CT_COLON))
+   if (  chunk_is_token(next, CT_TYPE)
+      || chunk_is_token(next, CT_WORD)
+      || chunk_is_token(next, CT_COLON))
    {
       // i.e. "enum xyz : unsigned int { ... };"
       // i.e. "enum class xyz : unsigned int { ... };"
@@ -327,7 +336,7 @@ void fix_enum_struct_union(chunk_t *pc)
       // xyz is a type
 
       // save the type if it exists
-      if (!chunk_is_token(next, CT_COLON))
+      if (chunk_is_not_token(next, CT_COLON))
       {
          set_chunk_parent(next, pc->type);
          prev = next;
@@ -340,10 +349,12 @@ void fix_enum_struct_union(chunk_t *pc)
       }
       set_chunk_parent(next, pc->type);
       auto const is_struct_or_class =
-         (chunk_is_token(pc, CT_STRUCT) || chunk_is_token(pc, CT_CLASS));
+         (  chunk_is_token(pc, CT_STRUCT)
+         || chunk_is_token(pc, CT_CLASS));
 
       // next up is either a colon, open brace, or open parenthesis (pawn)
-      if (language_is_set(LANG_PAWN) && chunk_is_token(next, CT_PAREN_OPEN))
+      if (  language_is_set(LANG_PAWN)
+         && chunk_is_token(next, CT_PAREN_OPEN))
       {
          next = set_paren_parent(next, CT_ENUM);
       }
@@ -372,7 +383,8 @@ void fix_enum_struct_union(chunk_t *pc)
             next = skip_parent_types(next);
          }
       }
-      else if (is_struct_or_class && chunk_is_token(next, CT_PAREN_OPEN))
+      else if (  is_struct_or_class
+              && chunk_is_token(next, CT_PAREN_OPEN))
       {
          // Fix #1267 structure attributes
          // struct __attribute__(align(x)) struct_name;
@@ -436,7 +448,8 @@ void fix_enum_struct_union(chunk_t *pc)
       set_chunk_parent(prev, CT_NONE);
    }
 
-   if (next == nullptr || chunk_is_token(next, CT_PAREN_CLOSE))
+   if (  next == nullptr
+      || chunk_is_token(next, CT_PAREN_CLOSE))
    {
       return;
    }
@@ -462,7 +475,7 @@ void fix_enum_struct_union(chunk_t *pc)
    // We are either pointing to a ';' or a variable
    while (  next != nullptr
          && !chunk_is_semicolon(next)
-         && next->type != CT_ASSIGN
+         && chunk_is_not_token(next, CT_ASSIGN)
          && !(in_fcn_paren ^ (next->flags & PCF_IN_FCN_DEF)).test_any())
    {
       if (next->level == pc->level)
@@ -476,13 +489,15 @@ void fix_enum_struct_union(chunk_t *pc)
          }
 
          if (  chunk_is_token(next, CT_STAR)
-            || (language_is_set(LANG_CPP) && chunk_is_token(next, CT_CARET)))
+            || (  language_is_set(LANG_CPP)
+               && chunk_is_token(next, CT_CARET)))
          {
             set_chunk_type(next, CT_PTR_TYPE);
          }
 
          // If we hit a comma in a function param, we are done
-         if (  (chunk_is_token(next, CT_COMMA) || chunk_is_token(next, CT_FPAREN_CLOSE))
+         if (  (  chunk_is_token(next, CT_COMMA)
+               || chunk_is_token(next, CT_FPAREN_CLOSE))
             && (next->flags.test_any(PCF_IN_FCN_DEF | PCF_IN_FCN_CALL)))
          {
             return;
@@ -491,8 +506,7 @@ void fix_enum_struct_union(chunk_t *pc)
       next = chunk_get_next_ncnl(next);
    }
 
-   if (  next != nullptr
-      && chunk_is_token(next, CT_SEMICOLON))
+   if (chunk_is_token(next, CT_SEMICOLON))
    {
       set_chunk_parent(next, pc->type);
    }
@@ -550,7 +564,8 @@ void fix_fcn_def_params(chunk_t *start)
          cs.Push_Back(pc);
       }
       else if (  chunk_is_token(pc, CT_AMP)
-              || (language_is_set(LANG_CPP) && chunk_is_str(pc, "&&", 2)))
+              || (  language_is_set(LANG_CPP)
+                 && chunk_is_str(pc, "&&", 2)))
       {
          set_chunk_type(pc, CT_BYREF);
          cs.Push_Back(pc);
@@ -559,11 +574,13 @@ void fix_fcn_def_params(chunk_t *start)
       {
          cs.Push_Back(pc);
       }
-      else if (chunk_is_token(pc, CT_WORD) || chunk_is_token(pc, CT_TYPE))
+      else if (  chunk_is_token(pc, CT_WORD)
+              || chunk_is_token(pc, CT_TYPE))
       {
          cs.Push_Back(pc);
       }
-      else if (chunk_is_token(pc, CT_COMMA) || chunk_is_token(pc, CT_ASSIGN))
+      else if (  chunk_is_token(pc, CT_COMMA)
+              || chunk_is_token(pc, CT_ASSIGN))
       {
          mark_variable_stack(cs, LFCNP);
 
@@ -585,7 +602,8 @@ void fix_type_cast(chunk_t *start)
 
    pc = chunk_get_next_ncnl(start);
 
-   if (pc == nullptr || pc->type != CT_ANGLE_OPEN)
+   if (  pc == nullptr
+      || chunk_is_not_token(pc, CT_ANGLE_OPEN))
    {
       return;
    }
@@ -593,7 +611,8 @@ void fix_type_cast(chunk_t *start)
    while (  ((pc = chunk_get_next_ncnl(pc)) != nullptr)
          && pc->level >= start->level)
    {
-      if (pc->level == start->level && chunk_is_token(pc, CT_ANGLE_CLOSE))
+      if (  pc->level == start->level
+         && chunk_is_token(pc, CT_ANGLE_CLOSE))
       {
          pc = chunk_get_next_ncnl(pc);
 
@@ -650,7 +669,8 @@ void fix_typedef(chunk_t *start)
             break;
          }
 
-         if (language_is_set(LANG_D) && chunk_is_token(next, CT_ASSIGN))
+         if (  language_is_set(LANG_D)
+            && chunk_is_token(next, CT_ASSIGN))
          {
             set_chunk_parent(next, CT_TYPEDEF);
             break;
@@ -735,9 +755,9 @@ void fix_typedef(chunk_t *start)
       return;
    }
 
-   if (  after->type != CT_ENUM
-      && after->type != CT_STRUCT
-      && after->type != CT_UNION)
+   if (  chunk_is_not_token(after, CT_ENUM)
+      && chunk_is_not_token(after, CT_STRUCT)
+      && chunk_is_not_token(after, CT_UNION))
    {
       if (the_type != nullptr)
       {
@@ -900,8 +920,8 @@ chunk_t *fix_variable_definition(chunk_t *start)
       {
          tmp_pc = cs.Get(idx)->m_pc;
 
-         if (  tmp_pc->type != CT_DC_MEMBER
-            && tmp_pc->type != CT_MEMBER)
+         if (  chunk_is_not_token(tmp_pc, CT_DC_MEMBER)
+            && chunk_is_not_token(tmp_pc, CT_MEMBER))
          {
             break;
          }
@@ -916,8 +936,8 @@ chunk_t *fix_variable_definition(chunk_t *start)
          idx--;
          tmp_pc = cs.Get(idx)->m_pc;
 
-         if (  tmp_pc->type != CT_WORD
-            && tmp_pc->type != CT_TYPE)
+         if (  chunk_is_not_token(tmp_pc, CT_WORD)
+            && chunk_is_not_token(tmp_pc, CT_TYPE))
          {
             break;
          }
@@ -970,6 +990,10 @@ void mark_class_ctor(chunk_t *start)
 
    chunk_t *pclass = chunk_get_next_ncnl(start, scope_e::PREPROC);
 
+   if (pclass == nullptr)
+   {
+      return;
+   }
    LOG_FMT(LFTOR, "%s(%d): pclass is '%s'\n",
            __func__, __LINE__, pclass->text());
    log_pcf_flags(LFTOR, pclass->flags);
@@ -1028,7 +1052,8 @@ void mark_class_ctor(chunk_t *start)
    }
 
    if (  pclass == nullptr
-      || (pclass->type != CT_TYPE && pclass->type != CT_WORD))
+      || (  chunk_is_not_token(pclass, CT_TYPE)
+         && chunk_is_not_token(pclass, CT_WORD)))
    {
       return;
    }
@@ -1061,7 +1086,8 @@ void mark_class_ctor(chunk_t *start)
            __func__, __LINE__, pclass->text(), pclass->orig_line, pc->text());
 
    // detect D template class: "class foo(x) { ... }"
-   if (language_is_set(LANG_D) && chunk_is_token(next, CT_PAREN_OPEN))              // Coverity CID 76004
+   if (  language_is_set(LANG_D)
+      && chunk_is_token(next, CT_PAREN_OPEN))              // Coverity CID 76004
    {
       set_chunk_parent(next, CT_TEMPLATE);
 
@@ -1075,7 +1101,8 @@ void mark_class_ctor(chunk_t *start)
    // Find the open brace, abort on semicolon
    pcf_flags_t flags = PCF_NONE;
 
-   while (pc != nullptr && pc->type != CT_BRACE_OPEN)
+   while (  pc != nullptr
+         && chunk_is_not_token(pc, CT_BRACE_OPEN))
    {
       LOG_FMT(LFTOR, " [%s]", pc->text());
 
@@ -1125,7 +1152,8 @@ void mark_class_ctor(chunk_t *start)
          continue;
       }
 
-      if (chunk_is_token(pc, CT_BRACE_CLOSE) && pc->brace_level < level)
+      if (  chunk_is_token(pc, CT_BRACE_CLOSE)
+         && pc->brace_level < level)
       {
          LOG_FMT(LFTOR, "%s(%d): orig_line is %zu, Hit brace close\n",
                  __func__, __LINE__, pc->orig_line);
@@ -1150,8 +1178,7 @@ void mark_class_ctor(chunk_t *start)
                  __func__, __LINE__, prev->text(), prev->orig_line, prev->orig_col, get_token_name(prev->type));
 
          // Issue #1003, next->type should not be CT_FPAREN_OPEN
-         if (  prev != nullptr
-            && (prev->type != CT_NEW))
+         if (chunk_is_not_token(prev, CT_NEW))
          {
             bool is_func_class_def = false;
 
@@ -1201,7 +1228,8 @@ void mark_cpp_constructor(chunk_t *pc)
 
    tmp = chunk_get_prev_ncnlni(pc);   // Issue #2279
 
-   if (chunk_is_token(tmp, CT_INV) || chunk_is_token(tmp, CT_DESTRUCTOR))
+   if (  chunk_is_token(tmp, CT_INV)
+      || chunk_is_token(tmp, CT_DESTRUCTOR))
    {
       set_chunk_type(tmp, CT_DESTRUCTOR);
       set_chunk_parent(pc, CT_DESTRUCTOR);
@@ -1233,7 +1261,8 @@ void mark_cpp_constructor(chunk_t *pc)
    bool hit_colon = false;
 
    while (  tmp != nullptr
-         && (tmp->type != CT_BRACE_OPEN || tmp->level != paren_open->level)
+         && (  chunk_is_not_token(tmp, CT_BRACE_OPEN)
+            || tmp->level != paren_open->level)
          && !chunk_is_semicolon(tmp))
    {
       LOG_FMT(LFTOR, "%s(%d): tmp is '%s', orig_line is %zu, orig_col is %zu\n",
@@ -1253,7 +1282,8 @@ void mark_cpp_constructor(chunk_t *pc)
       {
          var = skip_template_prev(chunk_get_prev_ncnlni(tmp));   // Issue #2279
 
-         if (chunk_is_token(var, CT_TYPE) || chunk_is_token(var, CT_WORD))
+         if (  chunk_is_token(var, CT_TYPE)
+            || chunk_is_token(var, CT_WORD))
          {
             set_chunk_type(var, CT_FUNC_CTOR_VAR);
             flag_parens(tmp, PCF_IN_FCN_CALL, CT_FPAREN_OPEN, CT_FUNC_CTOR_VAR, false);
@@ -1275,6 +1305,19 @@ void mark_cpp_constructor(chunk_t *pc)
       LOG_FMT(LFCN, "%s(%d):  Marked '%s' as FUNC_CLASS_PROTO on orig_line %zu, orig_col %zu\n",
               __func__, __LINE__, pc->text(), pc->orig_line, pc->orig_col);
    }
+   tmp = chunk_get_prev_ncnlni(pc); // Issue #2907
+
+   if (chunk_is_token(tmp, CT_DESTRUCTOR))
+   {
+      set_chunk_parent(tmp, pc->type);
+      tmp = chunk_get_prev_ncnlni(tmp);
+   }
+
+   while (chunk_is_token(tmp, CT_QUALIFIER))
+   {
+      set_chunk_parent(tmp, pc->type);
+      tmp = chunk_get_prev_ncnlni(tmp);
+   }
 } // mark_cpp_constructor
 
 
@@ -1301,16 +1344,18 @@ void mark_define_expressions(void)
       }
       else
       {
-         if (!pc->flags.test(PCF_IN_PREPROC) || chunk_is_token(pc, CT_PREPROC))
+         if (  !pc->flags.test(PCF_IN_PREPROC)
+            || chunk_is_token(pc, CT_PREPROC))
          {
             in_define = false;
          }
          else
          {
-            if (  pc->type != CT_MACRO
+            if (  chunk_is_not_token(pc, CT_MACRO)
                && (  first
                   || chunk_is_token(prev, CT_PAREN_OPEN)
                   || chunk_is_token(prev, CT_ARITH)
+                  || chunk_is_token(prev, CT_SHIFT)
                   || chunk_is_token(prev, CT_CARET)
                   || chunk_is_token(prev, CT_ASSIGN)
                   || chunk_is_token(prev, CT_COMPARE)
@@ -1357,15 +1402,15 @@ void mark_exec_sql(chunk_t *pc)
       }
    }
 
-   if (  pc->type != CT_SQL_BEGIN
+   if (  chunk_is_not_token(pc, CT_SQL_BEGIN)
       || tmp == nullptr
-      || tmp->type != CT_SEMICOLON)
+      || chunk_is_not_token(tmp, CT_SEMICOLON))
    {
       return;
    }
 
    for (tmp = chunk_get_next(tmp);
-        tmp != nullptr && tmp->type != CT_SQL_END;
+        tmp != nullptr && chunk_is_not_token(tmp, CT_SQL_END);
         tmp = chunk_get_next(tmp))
    {
       tmp->level++;
@@ -1396,7 +1441,8 @@ void mark_function_return_type(chunk_t *fname, chunk_t *start, c_token_t parent_
          {
             pc = skip_template_prev(pc);
 
-            if (pc == nullptr || chunk_is_token(pc, CT_TEMPLATE))
+            if (  pc == nullptr
+               || chunk_is_token(pc, CT_TEMPLATE))
             {
                //either expression is not complete or this is smth like 'template<T> void func()'
                //  - we are not interested in 'template<T>' part
@@ -1409,9 +1455,9 @@ void mark_function_return_type(chunk_t *fname, chunk_t *start, c_token_t parent_
          }
 
          if (  (  !chunk_is_type(pc)
-               && pc->type != CT_OPERATOR
-               && pc->type != CT_WORD
-               && pc->type != CT_ADDR)
+               && chunk_is_not_token(pc, CT_OPERATOR)
+               && chunk_is_not_token(pc, CT_WORD)
+               && chunk_is_not_token(pc, CT_ADDR))
             || pc->flags.test(PCF_IN_PREPROC))
          {
             break;
@@ -1428,7 +1474,8 @@ void mark_function_return_type(chunk_t *fname, chunk_t *start, c_token_t parent_
       // Changing words to types into tuple return types in CS.
       bool is_return_tuple = false;
 
-      if (chunk_is_token(pc, CT_PAREN_CLOSE) && !pc->flags.test(PCF_IN_PREPROC))
+      if (  chunk_is_token(pc, CT_PAREN_CLOSE)
+         && !pc->flags.test(PCF_IN_PREPROC))
       {
          first           = chunk_skip_to_match_rev(pc);
          is_return_tuple = true;
@@ -1446,8 +1493,9 @@ void mark_function_return_type(chunk_t *fname, chunk_t *start, c_token_t parent_
          chunk_t *prev = chunk_get_prev_ncnlni(pc);   // Issue #2279
 
          if (  !is_return_tuple
-            || pc->type != CT_WORD
-            || (prev != nullptr && prev->type != CT_TYPE))
+            || chunk_is_not_token(pc, CT_WORD)
+            || (  prev != nullptr
+               && chunk_is_not_token(prev, CT_TYPE)))
          {
             make_type(pc);
          }
@@ -1602,7 +1650,7 @@ void mark_function(chunk_t *pc)
          }
 
          if (  tmp != nullptr
-            && pc->type != CT_FUNC_CALL)
+            && chunk_is_not_token(pc, CT_FUNC_CALL))
          {
             // Mark the return type
             while (  (tmp = chunk_get_next_ncnl(tmp)) != pc
@@ -1694,7 +1742,8 @@ void mark_function(chunk_t *pc)
       {
          tmp2 = chunk_get_next_ncnl(tmp1);
 
-         if (!chunk_is_word(tmp1) || !chunk_is_token(tmp2, CT_DC_MEMBER))
+         if (  !chunk_is_word(tmp1)
+            || chunk_is_not_token(tmp2, CT_DC_MEMBER))
          {
             break;
          }
@@ -1825,7 +1874,8 @@ void mark_function(chunk_t *pc)
                  __func__, __LINE__, prev->text(), prev->orig_line, prev->orig_col,
                  get_token_name(prev->type));
 
-         if (chunk_is_token(prev, CT_WORD) || chunk_is_token(prev, CT_TYPE))
+         if (  chunk_is_token(prev, CT_WORD)
+            || chunk_is_token(prev, CT_TYPE))
          {
             if (pc->str.equals(prev->str))
             {
@@ -1961,9 +2011,9 @@ void mark_function(chunk_t *pc)
                prev = chunk_get_prev_ncnlnp(prev);
 
                if (  prev == nullptr
-                  || (  prev->type != CT_WORD
-                     && prev->type != CT_TYPE
-                     && prev->type != CT_THIS))
+                  || (  chunk_is_not_token(prev, CT_WORD)
+                     && chunk_is_not_token(prev, CT_TYPE)
+                     && chunk_is_not_token(prev, CT_THIS)))
                {
                   LOG_FMT(LFCN, "%s(%d): --? skipped MEMBER and landed on %s\n",
                           __func__, __LINE__, (prev == nullptr) ? "<null>" : get_token_name(prev->type));
@@ -2027,12 +2077,12 @@ void mark_function(chunk_t *pc)
             hit_star = true;
          }
 
-         if (  prev->type != CT_OPERATOR
-            && prev->type != CT_TSQUARE
-            && prev->type != CT_ANGLE_CLOSE
-            && prev->type != CT_QUALIFIER
-            && prev->type != CT_TYPE
-            && prev->type != CT_WORD
+         if (  chunk_is_not_token(prev, CT_OPERATOR)
+            && chunk_is_not_token(prev, CT_TSQUARE)
+            && chunk_is_not_token(prev, CT_ANGLE_CLOSE)
+            && chunk_is_not_token(prev, CT_QUALIFIER)
+            && chunk_is_not_token(prev, CT_TYPE)
+            && chunk_is_not_token(prev, CT_WORD)
             && !chunk_is_ptr_operator(prev))
          {
             LOG_FMT(LFCN, "%s(%d):  --> Stopping on prev is '%s', orig_line is %zu, orig_col is %zu, type is %s\n",
@@ -2040,9 +2090,11 @@ void mark_function(chunk_t *pc)
 
             // certain tokens are unlikely to precede a prototype or definition
             if (  chunk_is_token(prev, CT_ARITH)
+               || chunk_is_token(prev, CT_SHIFT)
                || chunk_is_token(prev, CT_ASSIGN)
                || chunk_is_token(prev, CT_COMMA)
-               || (chunk_is_token(prev, CT_STRING) && get_chunk_parent_type(prev) != CT_EXTERN)  // fixes issue 1259
+               || (  chunk_is_token(prev, CT_STRING)
+                  && get_chunk_parent_type(prev) != CT_EXTERN)  // fixes issue 1259
                || chunk_is_token(prev, CT_STRING_MULTI)
                || chunk_is_token(prev, CT_NUMBER)
                || chunk_is_token(prev, CT_NUMBER_FP)
@@ -2102,8 +2154,8 @@ void mark_function(chunk_t *pc)
                && get_chunk_parent_type(prev) != CT_D_CAST
                && get_chunk_parent_type(prev) != CT_MACRO_OPEN  // Issue #2726
                && get_chunk_parent_type(prev) != CT_MACRO_CLOSE)
-            || prev->type == CT_ASSIGN
-            || prev->type == CT_RETURN))
+            || chunk_is_token(prev, CT_ASSIGN)
+            || chunk_is_token(prev, CT_RETURN)))
       {
          LOG_FMT(LFCN, "%s(%d): -- overriding DEF due to prev is '%s', type is %s\n",
                  __func__, __LINE__, prev->text(), get_token_name(prev->type));
@@ -2120,7 +2172,8 @@ void mark_function(chunk_t *pc)
          while (  tmp != nullptr                     // Issue #2315
                && tmp != prev)
          {
-            if (chunk_is_token(tmp, CT_COMMA) && tmp->level == prev->level + 1)
+            if (  chunk_is_token(tmp, CT_COMMA)
+               && tmp->level == prev->level + 1)
             {
                LOG_FMT(LFCN, "%s(%d): -- overriding call due to tuple return type -- prev is '%s', type is %s\n",
                        __func__, __LINE__, prev->text(), get_token_name(prev->type));
@@ -2154,7 +2207,7 @@ void mark_function(chunk_t *pc)
       }
    }
 
-   if (pc->type != CT_FUNC_DEF)
+   if (chunk_is_not_token(pc, CT_FUNC_DEF))
    {
       LOG_FMT(LFCN, "%s(%d):  Detected type %s, text() is '%s', on orig_line %zu, orig_col %zu\n",
               __func__, __LINE__, get_token_name(pc->type),
@@ -2371,9 +2424,9 @@ void mark_function(chunk_t *pc)
       tmp = chunk_get_next_ncnl(paren_close);
       pcf_flags_t in_where_spec_flags = PCF_NONE;
 
-      while (  (tmp != nullptr)
-            && (tmp->type != CT_BRACE_OPEN)
-            && (tmp->type != CT_SEMICOLON))
+      while (  tmp != nullptr
+            && chunk_is_not_token(tmp, CT_BRACE_OPEN)
+            && chunk_is_not_token(tmp, CT_SEMICOLON))
       {
          mark_where_chunk(tmp, pc->type, tmp->flags | in_where_spec_flags);
          in_where_spec_flags = tmp->flags & PCF_IN_WHERE_SPEC;
@@ -2388,7 +2441,7 @@ void mark_function(chunk_t *pc)
       tmp = chunk_get_next_ncnl(paren_close);
 
       while (  tmp != nullptr
-            && tmp->type != CT_BRACE_OPEN)
+            && chunk_is_not_token(tmp, CT_BRACE_OPEN))
       {
          LOG_FMT(LFCN, "%s(%d): (13) SET TO CT_FUNC_DEF: orig_line is %zu, orig_col is %zu, text() '%s'\n",
                  __func__, __LINE__, tmp->orig_line, tmp->orig_col, tmp->text());
@@ -2479,7 +2532,8 @@ bool mark_function_type(chunk_t *pc)
    {
       pt = CT_FUNC_DEF;
    }
-   else if (chunk_is_token(aft, CT_SEMICOLON) || chunk_is_token(aft, CT_ASSIGN))
+   else if (  chunk_is_token(aft, CT_SEMICOLON)
+           || chunk_is_token(aft, CT_ASSIGN))
    {
       pt = CT_FUNC_PROTO;
    }
@@ -2677,7 +2731,8 @@ void mark_struct_union_body(chunk_t *start)
 
    while (  pc != nullptr
          && pc->level >= start->level
-         && !(pc->level == start->level && chunk_is_token(pc, CT_BRACE_CLOSE)))
+         && !(  pc->level == start->level
+             && chunk_is_token(pc, CT_BRACE_CLOSE)))
    {
       if (  chunk_is_token(pc, CT_BRACE_OPEN)
          || chunk_is_token(pc, CT_BRACE_CLOSE)
@@ -2839,7 +2894,9 @@ void mark_variable_stack(ChunkStack &cs, log_sev_t sev)
    // throw out the last word and mark the rest
    chunk_t *var_name = cs.Pop_Back();
 
-   if (var_name && var_name->prev->type == CT_DC_MEMBER)
+   if (  var_name != nullptr
+      && var_name->prev != nullptr
+      && var_name->prev->type == CT_DC_MEMBER)
    {
       cs.Push_Back(var_name);
    }
@@ -2854,7 +2911,8 @@ void mark_variable_stack(ChunkStack &cs, log_sev_t sev)
 
       while ((word_type = cs.Pop_Back()) != nullptr)
       {
-         if (chunk_is_token(word_type, CT_WORD) || chunk_is_token(word_type, CT_TYPE))
+         if (  chunk_is_token(word_type, CT_WORD)
+            || chunk_is_token(word_type, CT_TYPE))
          {
             LOG_FMT(LFCNP, "%s(%d): parameter on orig_line %zu, orig_col %zu: <%s> as TYPE\n",
                     __func__, __LINE__, var_name->orig_line, var_name->orig_col, word_type->text());
