@@ -7,11 +7,12 @@
  */
 #ifndef WIN32
 
+#include "uncrustify_types.h"
 #include <cstdlib>
 #include <string>
 
 
-bool unc_getenv(const char *name, std::string& str)
+bool unc_getenv(const char *name, std::string &str)
 {
    const char *val = getenv(name);
 
@@ -24,13 +25,16 @@ bool unc_getenv(const char *name, std::string& str)
 }
 
 
-bool unc_homedir(std::string& home)
+bool unc_homedir(std::string &home)
 {
-   if (unc_getenv("HOME", home))
-   {
-      return(true);
-   }
-   return(false);
+   return(unc_getenv("HOME", home));
+}
+
+
+void convert_log_zu2lu(char *fmt)
+{
+   UNUSED(fmt);
+   // nothing to do
 }
 
 #endif /* ifndef WIN32 */
