@@ -1,22 +1,23 @@
 /**
  * @file frame_list.h
- * Functions for the cpd.frames var, mainly used to handle preprocessor stuff
+ * mainly used to handle preprocessor stuff
  *
  * @author  Ben Gardner
  * @license GPL v2+
  */
+
 #ifndef PARSE_FRAME_H_INCLUDED
 #define PARSE_FRAME_H_INCLUDED
 
-#include "uncrustify_types.h"
 #include "ParseFrame.h"
+#include "uncrustify_types.h"
 
 
 /**
  * Push a copy of a ParseFrame onto the frames list.
  * This is called on #if and #ifdef.
  */
-void fl_push(ParseFrame &pf);
+void fl_push(std::vector<ParseFrame> &frames, ParseFrame &frm);
 
 
 /**
@@ -26,11 +27,14 @@ void fl_push(ParseFrame &pf);
  *
  * This is called on #endif
  */
-void fl_pop(ParseFrame &pf);
+void fl_pop(std::vector<ParseFrame> &frames, ParseFrame &pf);
 
 
+// TODO: this name is dumb:
+// - what is it checking?
+// - why does is much more than simple checks, it allters kinds of stuff
 //! Returns the pp_indent to use for this line
-int fl_check(ParseFrame &frm, chunk_t *pc);
+int fl_check(std::vector<ParseFrame> &frames, ParseFrame &frm, int &pp_level, chunk_t *pc);
 
 
 #endif /* PARSE_FRAME_H_INCLUDED */
