@@ -93,6 +93,8 @@ void pawn_scrub_vsemi(void)
 {
    LOG_FUNC_ENTRY();
 
+   log_rule_B("mod_pawn_semicolon");
+
    if (!options::mod_pawn_semicolon())
    {
       return;
@@ -132,6 +134,7 @@ static bool pawn_continued(chunk_t *pc, size_t br_level)
 
    if (  pc->level > br_level
       || chunk_is_token(pc, CT_ARITH)
+      || chunk_is_token(pc, CT_SHIFT)
       || chunk_is_token(pc, CT_CARET)
       || chunk_is_token(pc, CT_QUESTION)
       || chunk_is_token(pc, CT_BOOL)
