@@ -1,14 +1,15 @@
 /**
  * @file log_rules.cpp
+ * is an extract from space.cpp
  *
  * @author  Guy Maurel
  * @license GPL v2+
  */
 
 #include "log_rules.h"
+#include <string.h>
 
 
-// is an extract from space.cpp
 void log_rule2(const char *func, size_t line, const char *rule, chunk_t *first, chunk_t *second)
 {
    LOG_FUNC_ENTRY();
@@ -26,8 +27,36 @@ void log_rule2(const char *func, size_t line, const char *rule, chunk_t *first,
 }
 
 
-void log_rule3(const char *func, size_t line, const char *rule)
+void log_rule3(const char *func, const char *rule)
 {
-   LOG_FMT(LSPACE, "%s(%zu): rule is '%s'\n",
-           func, line, rule);
+   const char *where = nullptr;
+
+#ifdef WIN32
+   // some Windows provide "ABC::XYZ::function_Name" as __func__
+   // we look for the last ':' character
+   // a function rindex cannot be found
+   size_t length_of_string = strlen(func);
+
+   for (int which = length_of_string - 1; which > 0; which--)
+   {
+      char oneChar = func[which];
+
+      if (oneChar == ':')
+      {
+         where = func + which;
+         break;
+      }
+   }
+#else // not WIN32
+   where = rindex(func, ':');
+#endif /* ifdef WIN32 */
+
+   if (where == nullptr)
+   {
+      LOG_FMT(LSPACE, "log_rule(%s): rule is '%s'\n", func, rule);
+   }
+   else
+   {
+      LOG_FMT(LSPACE, "log_rule(%s): rule is '%s'\n", where + 1, rule);
+   }
 }
