@@ -15,11 +15,6 @@
 
 using namespace uncrustify;
 
-void log_rule(const char *rule);
-
-
-void log_rule_B(const char *rule);
-
 
 #define log_rule(rule)                                             \
    do { if (log_sev_on(LSPACE)) {                                  \
@@ -27,15 +22,15 @@ void log_rule_B(const char *rule);
    } while (0)
 
 
-#define log_rule_B(rule)                            \
-   do { if (log_sev_on(LSPACE)) {                   \
-           log_rule3(__func__, __LINE__, (rule)); } \
+#define log_rule_B(rule)                  \
+   do { if (log_sev_on(LSPACE)) {         \
+           log_rule3(__func__, (rule)); } \
    } while (0)
 
 
 void log_rule2(const char *func, size_t line, const char *rule, chunk_t *first, chunk_t *second);
 
 
-void log_rule3(const char *func, size_t line, const char *rule);
+void log_rule3(const char *func, const char *rule);
 
 #endif /* LOG_RULES_H_INCLUDED */
