@@ -186,22 +186,25 @@ void log_fmt(log_sev_t sev, const char *fmt, ...)
    {
       return;
    }
-
    // Issue #1203
-   if (strlen(fmt) == 0)
+   unsigned int length = strlen(fmt);
+
+   if (length == 0)
    {
       return;
    }
-#define BUFFERLENGTH    200
-   char         buf[BUFFERLENGTH];
-   // it MUST be a 'unsigned int' variable to be runable under windows
-   unsigned int length = strlen(fmt);
+   // the value of buffer_length is experimental
+   const int buffer_length = 4100;
+   char      buf[buffer_length];
 
-   if (length >= BUFFERLENGTH)
+   // it MUST be a 'unsigned int' variable to be runable under windows
+
+   if (length >= buffer_length)
    {
-      fprintf(stderr, "FATAL: The variable 'buf' is not big enought:\n");
-      fprintf(stderr, "   it should be bigger as = %u\n", length);
+      fprintf(stderr, "FATAL(1): The variable 'buf' is not big enought:\n");
+      fprintf(stderr, "   it should be bigger as %u\n", length);
       fprintf(stderr, "Please make a report.\n");
+      fprintf(stderr, "For the buffer: %s\n", fmt);
       exit(EX_SOFTWARE);
    }
    memcpy(buf, fmt, length);
@@ -219,8 +222,10 @@ void log_fmt(log_sev_t sev, const char *fmt, ...)
       size_t  cap = log_start(sev);
       // Add on the variable log parameters to the log string
       va_list args;        // determine list of arguments ...
-      va_start(args, fmt); //  ... that follow after parameter fmt
-      size_t  lenX = static_cast<size_t>(vsnprintf(&g_log.bufX[g_log.buf_len], cap, buf, args));
+      va_start(args, fmt);
+      size_t  which  = g_log.buf_len;
+      char    *where = &g_log.bufX[which];
+      size_t  lenX   = static_cast<size_t>(vsnprintf(where, cap, buf, args));
       va_end(args);
 
       if (lenX > 0)
@@ -233,7 +238,17 @@ void log_fmt(log_sev_t sev, const char *fmt, ...)
          // that the output was truncated.
          if (lenX > cap)
          {
-            size_t X = g_log.bufX.size() * 2;
+            size_t bufXLength = g_log.bufX.size();
+            size_t X          = bufXLength * 2;
+
+            if (X >= buffer_length)
+            {
+               fprintf(stderr, "FATAL(2): The variable 'buf' is not big enought:\n");
+               fprintf(stderr, "   it should be bigger as %zu\n", X);
+               fprintf(stderr, "Please make a report.\n");
+               fprintf(stderr, "For the buffer: %s\n", fmt);
+               exit(EX_SOFTWARE);
+            }
             g_log.bufX.resize(X);
          }
          else
