@@ -5,12 +5,17 @@
  * @author  Ben Gardner
  * @license GPL v2+
  */
+
 #ifndef NEWLINES_H_INCLUDED
 #define NEWLINES_H_INCLUDED
 
-#include "uncrustify_types.h"
 #include "chunk_list.h"
+#include "uncrustify_types.h"
 
+/**
+ * Double the newline, if allowed.
+ */
+void double_newline(chunk_t *nl);
 
 /**
  * Remove all extra newlines.
@@ -18,11 +23,18 @@
  */
 void newlines_remove_newlines(void);
 
+/** Step through all chunks, altering newlines inside parens of if/for/while/do as needed.
+ * Handles the style options: nl_multi_line_sparen_open, nl_multi_line_sparen_close, nl_before_if_closing_paren
+ */
+void newlines_sparens();
 
 //! Step through all chunks.
 void newlines_cleanup_braces(bool first);
 
 
+void newlines_cleanup_angles();
+
+
 //! Handle insertion/removal of blank lines before if/for/while/do and functions
 void newlines_insert_blank_lines(void);
 
