@@ -5,14 +5,18 @@
  * @author  Ben Gardner
  * @license GPL v2+
  */
+
 #include "parens.h"
-#include "uncrustify_types.h"
+
 #include "chunk_list.h"
+#include "log_rules.h"
+#include "unc_ctype.h"
+#include "uncrustify.h"
+#include "uncrustify_types.h"
+
 #include <cstdio>
 #include <cstdlib>
 #include <cstring>
-#include "unc_ctype.h"
-#include "uncrustify.h"
 
 using namespace uncrustify;
 
@@ -46,21 +50,24 @@ void do_parens(void)
 {
    LOG_FUNC_ENTRY();
 
+   log_rule_B("mod_full_paren_if_bool");
+
    if (options::mod_full_paren_if_bool())
    {
       chunk_t *pc = chunk_get_head();
+
       while ((pc = chunk_get_next_ncnl(pc)) != nullptr)
       {
          if (  pc->type != CT_SPAREN_OPEN
-            || (  pc->parent_type != CT_IF
-               && pc->parent_type != CT_ELSEIF
-               && pc->parent_type != CT_SWITCH))
+            || (  get_chunk_parent_type(pc) != CT_IF
+               && get_chunk_parent_type(pc) != CT_ELSEIF
+               && get_chunk_parent_type(pc) != CT_SWITCH))
          {
             continue;
          }
-
          // Grab the close sparen
          chunk_t *pclose = chunk_get_next_type(pc, CT_SPAREN_CLOSE, pc->level, scope_e::PREPROC);
+
          if (pclose != nullptr)
          {
             check_bool_parens(pc, pclose, 0);
@@ -82,15 +89,16 @@ static void add_parens_between(chunk_t *first, chunk_t *last)
 
    // Don't do anything if we have a bad sequence, ie "&& )"
    chunk_t *first_n = chunk_get_next_ncnl(first);
+
    if (first_n == last)
    {
       return;
    }
-
    chunk_t pc;
+
+   set_chunk_type(&pc, CT_PAREN_OPEN);
    pc.orig_line   = first_n->orig_line;
    pc.orig_col    = first_n->orig_col;
-   pc.type        = CT_PAREN_OPEN;
    pc.str         = "(";
    pc.flags       = first_n->flags & PCF_COPY_FLAGS;
    pc.level       = first_n->level;
@@ -100,9 +108,10 @@ static void add_parens_between(chunk_t *first, chunk_t *last)
    chunk_add_before(&pc, first_n);
 
    chunk_t *last_p = chunk_get_prev_ncnl(last, scope_e::PREPROC);
+
+   set_chunk_type(&pc, CT_PAREN_CLOSE);
    pc.orig_line   = last_p->orig_line;
    pc.orig_col    = last_p->orig_col;
-   pc.type        = CT_PAREN_CLOSE;
    pc.str         = ")";
    pc.flags       = last_p->flags & PCF_COPY_FLAGS;
    pc.level       = last_p->level;
@@ -117,6 +126,7 @@ static void add_parens_between(chunk_t *first, chunk_t *last)
    {
       tmp->level++;
    }
+
    last_p->level++;
 } // add_parens_between
 
@@ -135,9 +145,10 @@ static void check_bool_parens(chunk_t *popen, chunk_t *pclose, int nest)
            popen->level);
 
    chunk_t *pc = popen;
+
    while ((pc = chunk_get_next_ncnl(pc)) != nullptr && pc != pclose)
    {
-      if (pc->flags & PCF_IN_PREPROC)
+      if (pc->flags.test(PCF_IN_PREPROC))
       {
          LOG_FMT(LPARADD2, " -- bail on PP %s [%s] at line %zu col %zu, level %zu\n",
                  get_token_name(pc->type),
@@ -153,9 +164,11 @@ static void check_bool_parens(chunk_t *popen, chunk_t *pclose, int nest)
          LOG_FMT(LPARADD2, " -- %s [%s] at line %zu col %zu, level %zu\n",
                  get_token_name(pc->type),
                  pc->text(), pc->orig_line, pc->orig_col, pc->level);
+
          if (hit_compare)
          {
             hit_compare = false;
+
             if (!language_is_set(LANG_CS))
             {
                add_parens_between(ref, pc);
@@ -172,6 +185,7 @@ static void check_bool_parens(chunk_t *popen, chunk_t *pclose, int nest)
       else if (chunk_is_paren_open(pc))
       {
          chunk_t *next = chunk_skip_to_match(pc);
+
          if (next != nullptr)
          {
             check_bool_parens(pc, next, nest + 1);
