@@ -5,14 +5,16 @@
  * @author  Ben Gardner
  * @license GPL v2+
  */
+
 #ifndef C_PARSE_PROTOTYPES_H_INCLUDED
 #define C_PARSE_PROTOTYPES_H_INCLUDED
 
-#include "uncrustify_types.h"
 #include "chunk_list.h"
+#include "log_rules.h"
+#include "uncrustify_types.h"
 
-#include <string>
 #include <deque>
+#include <string>
 
 
 /**
@@ -29,11 +31,13 @@ static inline size_t calc_next_tab_column(size_t col, size_t tabsize)
    {
       col = 1;
    }
+
    if (cpd.frag_cols > 0)
    {
       col += cpd.frag_cols - 1;
    }
    col = 1 + ((((col - 1) / tabsize) + 1) * tabsize);
+
    if (cpd.frag_cols > 0)
    {
       col -= cpd.frag_cols - 1;
@@ -50,6 +54,7 @@ static inline size_t calc_next_tab_column(size_t col, size_t tabsize)
  */
 static inline size_t next_tab_column(size_t col)
 {
+   log_rule_B("output_tab_size");
    return(calc_next_tab_column(col, uncrustify::options::output_tab_size()));
 }
 
