@@ -17,7 +17,6 @@
 
 using namespace uncrustify;
 
-
 Option<std::string>  *include_category_options[] =
 {
    &options::include_category_0,
@@ -209,12 +208,13 @@ static int compare_chunks(chunk_t *pc1, chunk_t *pc2, bool tcare)
       auto const &s1_ext = chunk_sort_str(pc1);
       auto const &s2_ext = chunk_sort_str(pc2);
 
+      log_rule_B("mod_sort_incl_import_ignore_extension");
       auto const &s1 = (options::mod_sort_incl_import_ignore_extension()) ? get_text_without_ext(s1_ext) : s1_ext;
       auto const &s2 = (options::mod_sort_incl_import_ignore_extension()) ? get_text_without_ext(s2_ext) : s2_ext;
+      log_rule_B("mod_sort_incl_import_prioritize_filename");
 
       if (options::mod_sort_incl_import_prioritize_filename())
       {
-         log_rule_B("mod_sort_incl_import_prioritize_filename");
          bool s1_contains_filename = text_contains_filename_without_ext(s1.c_str());
          bool s2_contains_filename = text_contains_filename_without_ext(s2.c_str());
 
@@ -372,6 +372,7 @@ static void do_the_sort(chunk_t **chunks, size_t num_chunks)
       if (min_idx != start_idx)
       {
          chunk_swap_lines(chunks[start_idx], chunks[min_idx]);
+         log_rule_B("mod_sort_incl_import_grouping_enabled");
 
          if (options::mod_sort_incl_import_grouping_enabled())
          {
@@ -445,6 +446,7 @@ static void delete_chunks_on_line_having_chunk(chunk_t *chunk)
 static void dedupe_imports(chunk_t **chunks, size_t num_chunks)
 {
    LOG_FUNC_ENTRY();
+   log_rule_B("mod_sort_case_sensitive");
 
    for (size_t idx = 1; idx < num_chunks; idx++)
    {
@@ -559,23 +561,29 @@ static void group_imports_by_adding_newlines(chunk_t **chunks, size_t num_chunks
 void sort_imports(void)
 {
    LOG_FUNC_ENTRY();
-   chunk_t *chunks[MAX_NUMBER_TO_SORT];
-   size_t  num_chunks  = 0;
-   chunk_t *p_last     = nullptr;
-   chunk_t *p_imp      = nullptr;
-   chunk_t *p_imp_last = nullptr;
+   const int max_number_to_sort                        = 1024;
+   const int max_lines_to_check_for_sort_after_include = 128;
+   const int max_gap_threshold_between_include_to_sort = 32;
+
+   chunk_t   *chunks[max_number_to_sort];
+   size_t    num_chunks  = 0;
+   chunk_t   *p_last     = nullptr;
+   chunk_t   *p_imp      = nullptr;
+   chunk_t   *p_imp_last = nullptr;
 
    prepare_categories();
 
    chunk_t *pc = chunk_get_head();
 
+   log_rule_B("mod_sort_incl_import_grouping_enabled");
+
    while (pc != nullptr)
    {
       // Simple optimization to limit the sorting. Any MAX_LINES_TO_CHECK_AFTER_INCLUDE lines after last
       // import is seen are ignore from sorting.
       if (  options::mod_sort_incl_import_grouping_enabled()
          && p_imp_last != nullptr
-         && (pc->orig_line - p_imp_last->orig_line) > MAX_LINES_TO_CHECK_FOR_SORT_AFTER_INCLUDE)
+         && (pc->orig_line - p_imp_last->orig_line) > max_lines_to_check_for_sort_after_include)
       {
          break;
       }
@@ -590,7 +598,7 @@ void sort_imports(void)
             && (  chunk_is_token(p_last, CT_SEMICOLON)
                || p_imp->flags.test(PCF_IN_PREPROC)))
          {
-            if (num_chunks < MAX_NUMBER_TO_SORT)
+            if (num_chunks < max_number_to_sort)
             {
                LOG_FMT(LSORT, "%s(%d): p_imp is %s\n",
                        __func__, __LINE__, p_imp->text());
@@ -598,7 +606,7 @@ void sort_imports(void)
             }
             else
             {
-               fprintf(stderr, "Number of 'import' to be sorted is too big for the current value %d.\n", MAX_NUMBER_TO_SORT);
+               fprintf(stderr, "Number of 'import' to be sorted is too big for the current value %d.\n", max_number_to_sort);
                fprintf(stderr, "Please make a report.\n");
                log_flush(true);
                cpd.error_count++;
@@ -606,17 +614,20 @@ void sort_imports(void)
             }
             did_import = true;
          }
+         log_rule_B("mod_sort_incl_import_grouping_enabled");
 
          if (  !did_import
             || (  !options::mod_sort_incl_import_grouping_enabled()
                && pc->nl_count > 1)
             || (  options::mod_sort_incl_import_grouping_enabled()
                && p_imp_last != nullptr
-               && (pc->orig_line - p_imp_last->orig_line) > MAX_GAP_THRESHOLD_BETWEEN_INCLUDE_TO_SORT)
+               && (pc->orig_line - p_imp_last->orig_line) > max_gap_threshold_between_include_to_sort)
             || next == nullptr)
          {
             if (num_chunks > 1)
             {
+               log_rule_B("mod_sort_incl_import_grouping_enabled");
+
                if (options::mod_sort_incl_import_grouping_enabled())
                {
                   remove_blank_lines_between_imports(chunks, num_chunks);
