@@ -18,6 +18,8 @@
 #include "combine.h"
 #include "combine_skip.h"
 #include "error_types.h"
+#include "flag_braced_init_list.h"
+#include "flag_decltype.h"
 #include "keywords.h"
 #include "language_tools.h"
 #include "log_rules.h"
@@ -105,7 +107,7 @@ static chunk_t *handle_double_angle_close(chunk_t *pc)
          && get_chunk_parent_type(next) == CT_NONE)
       {
          pc->str.append('>');
-         set_chunk_type(pc, CT_ARITH);
+         set_chunk_type(pc, CT_SHIFT);
          pc->orig_col_end = next->orig_col_end;
 
          chunk_t *tmp = chunk_get_next_ncnl(next);
@@ -475,6 +477,11 @@ void tokenize_cleanup(void)
          in_type_cast = true;
       }
 
+      if (chunk_is_token(pc, CT_DECLTYPE))
+      {
+         flag_cpp_decltype(pc);
+      }
+
       // Change angle open/close to CT_COMPARE, if not a template thingy
       if (  chunk_is_token(pc, CT_ANGLE_OPEN)
          && pc->parent_type != CT_TYPE_CAST)
@@ -525,7 +532,11 @@ void tokenize_cleanup(void)
             && chunk_is_token(prev, CT_WORD)
             && (  chunk_is_token(next, CT_PAREN_OPEN)
                || chunk_is_token(next, CT_WORD)
-               || chunk_is_token(next, CT_TYPE)))
+               || chunk_is_token(next, CT_TYPE)
+               || chunk_is_token(next, CT_NUMBER)
+               || chunk_is_token(next, CT_NUMBER_FP)
+               || chunk_is_token(next, CT_STRING)
+               || chunk_is_token(next, CT_STRING_MULTI)))
          {
             set_chunk_type(pc, CT_D_TEMPLATE);
          }
@@ -564,6 +575,14 @@ void tokenize_cleanup(void)
          {
             set_chunk_type(pc, CT_TYPE);
          }
+
+         // Set parent type for 'if constexpr'
+         if (  chunk_is_token(prev, CT_IF)
+            && chunk_is_token(pc, CT_QUALIFIER)
+            && chunk_is_str(pc, "constexpr", 9))
+         {
+            set_chunk_type(pc, CT_CONSTEXPR);
+         }
       }
 
       // Change get/set to CT_WORD if not followed by a brace open
@@ -1145,11 +1164,15 @@ static void check_template(chunk_t *start, bool in_type_cast)
             }
          }
 
-         if (pc->type == CT_PAREN_OPEN)
+         if (chunk_is_token(pc, CT_DECLTYPE))
+         {
+            flag_cpp_decltype(pc);
+         }
+         else if (chunk_is_token(pc, CT_PAREN_OPEN))
          {
             ++parens;
          }
-         else if (pc->type == CT_PAREN_CLOSE)
+         else if (chunk_is_token(pc, CT_PAREN_CLOSE))
          {
             --parens;
          }
@@ -1185,10 +1208,23 @@ static void check_template(chunk_t *start, bool in_type_cast)
    {
       /*
        * We may have something like "a< ... >", which is a template where
-       * '...' may consist of anything except braces {}, a semicolon, and
-       * unbalanced parens.
-       * if we are inside an 'if' statement and hit a CT_BOOL, then it isn't a
-       * template.
+       * '...' may consist of anything except a semicolon, unbalanced
+       * parens, or braces (with one exception being braced initializers
+       * embedded within decltypes).
+       *
+       * For example, braces may be encountered as such in the following
+       * snippet of valid C++ code:
+       *
+       * template<typename T,
+       *          typename = enable_if_t<is_same<typename decay<T>::type,
+       *                                          decltype (make_index_sequence<5> { })>::value>>
+       * void foo(T &&arg)
+       * {
+       *
+       * }
+       *
+       * Finally, if we are inside an 'if' statement and hit a CT_BOOL,
+       * then it isn't a template.
        */
 
       // A template requires a word/type right before the open angle
@@ -1215,13 +1251,33 @@ static void check_template(chunk_t *start, bool in_type_cast)
       while ((pc = chunk_get_prev_ncnl(pc, scope_e::PREPROC)) != nullptr)
       {
          if (  (chunk_is_token(pc, CT_SEMICOLON) && hit_semicolon)
-            || chunk_is_token(pc, CT_BRACE_OPEN)
-            || chunk_is_token(pc, CT_BRACE_CLOSE)
             || chunk_is_token(pc, CT_SQUARE_CLOSE))
          {
             break;
          }
 
+         if (chunk_is_token(pc, CT_DECLTYPE))
+         {
+            flag_cpp_decltype(pc);
+         }
+
+         if (chunk_is_token(pc, CT_BRACE_OPEN))
+         {
+            if (  !pc->flags.test(PCF_IN_DECLTYPE)
+               || !detect_cpp_braced_init_list(pc->prev, pc))
+            {
+               break;
+            }
+            flag_cpp_braced_init_list(pc->prev, pc);
+         }
+
+         if (  chunk_is_token(pc, CT_BRACE_CLOSE)
+            && get_chunk_parent_type(pc) != CT_BRACED_INIT_LIST
+            && !pc->flags.test(PCF_IN_DECLTYPE))
+         {
+            break;
+         }
+
          if (chunk_is_token(pc, CT_SEMICOLON) && !hit_semicolon)
          {
             hit_semicolon = true;
@@ -1241,8 +1297,8 @@ static void check_template(chunk_t *start, bool in_type_cast)
        * Scan forward to the angle close
        * If we have a comparison in there, then it can't be a template.
        */
-#define MAX_NUMBER_OF_TOKEN    1024
-      c_token_t tokens[MAX_NUMBER_OF_TOKEN];
+      const int max_token_count = 1024;
+      c_token_t tokens[max_token_count];
       size_t    num_tokens = 1;
 
       tokens[0] = CT_ANGLE_OPEN;
@@ -1294,21 +1350,43 @@ static void check_template(chunk_t *start, bool in_type_cast)
          {
             break;
          }
-         else if (  chunk_is_token(pc, CT_BRACE_OPEN)
-                 || chunk_is_token(pc, CT_BRACE_CLOSE)
-                 || chunk_is_token(pc, CT_SEMICOLON))
+         else if (chunk_is_token(pc, CT_BRACE_OPEN))
+         {
+            if (  !pc->flags.test(PCF_IN_DECLTYPE)
+               || !detect_cpp_braced_init_list(pc->prev, pc))
+            {
+               break;
+            }
+            auto brace_open  = chunk_get_next_ncnl(pc);
+            auto brace_close = chunk_skip_to_match(brace_open);
+
+            set_chunk_parent(brace_open, CT_BRACED_INIT_LIST);
+            set_chunk_parent(brace_close, CT_BRACED_INIT_LIST);
+         }
+         else if (  chunk_is_token(pc, CT_BRACE_CLOSE)
+                 && get_chunk_parent_type(pc) != CT_BRACED_INIT_LIST
+                 && !pc->flags.test(PCF_IN_DECLTYPE))
+         {
+            break;
+         }
+         else if (chunk_is_token(pc, CT_SEMICOLON))
          {
             break;
          }
          else if (chunk_is_token(pc, CT_PAREN_OPEN))
          {
-            if (num_tokens >= MAX_NUMBER_OF_TOKEN - 1)
+            if (num_tokens >= max_token_count - 1)
             {
                break;
             }
             tokens[num_tokens] = CT_PAREN_OPEN;
             num_tokens++;
          }
+         else if (  chunk_is_token(pc, CT_QUESTION)                    // Issue #2949
+                 && language_is_set(LANG_CPP))
+         {
+            break;
+         }
          else if (chunk_is_token(pc, CT_PAREN_CLOSE))
          {
             if (num_tokens == 0)
@@ -1392,7 +1470,8 @@ static void check_template_arg(chunk_t *start, chunk_t *end)
       if (next->type != CT_PAREN_OPEN)
       {
          if (  chunk_is_token(pc, CT_NUMBER)
-            || chunk_is_token(pc, CT_ARITH))
+            || chunk_is_token(pc, CT_ARITH)
+            || chunk_is_token(pc, CT_SHIFT))
          {
             expressionIsNumeric = true;
             break;
