@@ -300,11 +300,13 @@ void usage(const char *argv0)
            " --set <option>=<value>   : Sets a new value to a config option.\n"
            "\n"
            "Debug Options:\n"
-           " -p FILE      : Dump debug info into FILE, or to stdout if FILE is set to '-'.\n"
-           "                Must be used in combination with '-f FILE'\n"
-           " -L SEV       : Set the log severity (see log_levels.h; note 'A' = 'all')\n"
-           " -s           : Show the log severity in the logs.\n"
-           " --decode     : Decode remaining args (chunk flags) and exit.\n"
+           " -p FILE            : Dump debug info into FILE, or to stdout if FILE is set to '-'.\n"
+           "                      Must be used in combination with '-f FILE'.\n"
+           " --debug-csv-format : Dump debug info to file in csv-delimited format.\n"
+           "                      Must be used in combination with '-p FILE', where FILE is not set to '-'\n"
+           " -L SEV             : Set the log severity (see log_levels.h; note 'A' = 'all')\n"
+           " -s                 : Show the log severity in the logs.\n"
+           " --decode           : Decode remaining args (chunk flags) and exit.\n"
            "\n"
            "Usage Examples\n"
            "cat foo.d | uncrustify -q -c my.cfg -l d\n"
@@ -428,7 +430,7 @@ int main(int argc, char *argv[])
    }
 #ifdef DEBUG
    // make sure we have 'name' not too big
-#define MAXLENGTHOFTHENAME    19
+   const int max_name_length = 19;
 
    // maxLengthOfTheName must be consider at the format line at the file
    // output.cpp, line 427: fprintf(pfile, "# Line              Tag                Parent...
@@ -436,14 +438,14 @@ int main(int argc, char *argv[])
    // here                                                xx xx   xx xx
    for (size_t token = 0; token < ARRAY_SIZE(token_names); token++)
    {
-      size_t lengthOfTheName = strlen(token_names[token]);
+      const size_t name_length = strlen(token_names[token]);
 
-      if (lengthOfTheName > MAXLENGTHOFTHENAME)
+      if (name_length > max_name_length)
       {
          fprintf(stderr, "%s(%d): The token name '%s' is too long (%d)\n",
-                 __func__, __LINE__, token_names[token], (int)lengthOfTheName);
+                 __func__, __LINE__, token_names[token], static_cast<int>(name_length));
          fprintf(stderr, "%s(%d): the max token name length is %d\n",
-                 __func__, __LINE__, MAXLENGTHOFTHENAME);
+                 __func__, __LINE__, max_name_length);
          log_flush(true);
          exit(EX_SOFTWARE);
       }
@@ -613,17 +615,41 @@ int main(int argc, char *argv[])
    {
       // not using a file list, source_list is nullptr
    }
-   const char *prefix = arg.Param("--prefix");
-   const char *suffix = arg.Param("--suffix");
-   const char *assume = arg.Param("--assume");
+   const char  *prefix = arg.Param("--prefix");
+   const char  *suffix = arg.Param("--suffix");
+   const char  *assume = arg.Param("--assume");
 
-   bool       no_backup        = arg.Present("--no-backup");
-   bool       replace          = arg.Present("--replace");
-   bool       keep_mtime       = arg.Present("--mtime");
-   bool       update_config    = arg.Present("--update-config");
-   bool       update_config_wd = arg.Present("--update-config-with-doc");
-   bool       detect           = arg.Present("--detect");
+   bool        no_backup        = arg.Present("--no-backup");
+   bool        replace          = arg.Present("--replace");
+   bool        keep_mtime       = arg.Present("--mtime");
+   bool        update_config    = arg.Present("--update-config");
+   bool        update_config_wd = arg.Present("--update-config-with-doc");
+   bool        detect           = arg.Present("--detect");
+   bool        pfile_csv        = arg.Present("--debug-csv-format");
 
+   std::string parsed_file_csv;
+
+   if (pfile_csv)
+   {
+      if (  parsed_file == nullptr
+         || (  parsed_file[0] == '-'
+            && !parsed_file[1]))
+      {
+         fprintf(stderr,
+                 "FAIL: --debug-csv-format option must be used in combination with '-p FILE', where FILE\n"
+                 "      is not set to '-'\n");
+         log_flush(true);
+         exit(EX_CONFIG);
+      }
+      else if (!ends_with(parsed_file, ".csv", false))
+      {
+         parsed_file_csv = parsed_file;
+
+         // user-specified parsed filename does not end in a ".csv" extension, so add it
+         parsed_file_csv += ".csv";
+         parsed_file      = parsed_file_csv.c_str();
+      }
+   }
    // Grab the output override
    const char *output_file = arg.Param("-o");
 
@@ -715,17 +741,19 @@ int main(int argc, char *argv[])
    // Set config options using command line arguments.
    idx = 0;
 
+   const size_t max_args_length = 256;
+
    while ((p_arg = arg.Params("--set", idx)) != nullptr)
    {
       size_t argLength = strlen(p_arg);
-#define MAXLENGTHFORARG    256
-      if (argLength > MAXLENGTHFORARG)
+
+      if (argLength > max_args_length)
       {
          fprintf(stderr, "The buffer is to short for the set argument '%s'\n", p_arg);
          log_flush(true);
          exit(EX_SOFTWARE);
       }
-      char buffer[MAXLENGTHFORARG];
+      char buffer[max_args_length];
       strcpy(buffer, p_arg);
 
       // Tokenize and extract key and value
@@ -782,6 +810,20 @@ int main(int argc, char *argv[])
 
       return(EXIT_SUCCESS);
    }
+   // Set the number of second(s) before terminating formatting the current file.
+#ifdef WIN32
+   if (options::debug_timeout() > 0)
+   {
+      fprintf(stderr, "The option 'debug_timeout' is not available under Windows.\n");
+      log_flush(true);
+      exit(EX_SOFTWARE);
+   }
+#else
+   if (options::debug_timeout() > 0)
+   {
+      alarm(options::debug_timeout());
+   }
+#endif // ifdef WIN32
 
    if (detect)
    {
@@ -1036,17 +1078,6 @@ static bool read_stdin(file_mem &fm)
    // Re-open stdin in binary mode to preserve newline characters
 #ifdef WIN32
    _setmode(_fileno(stdin), _O_BINARY);
-#else
-   FILE *my_stdin = stdin;  // Reopen stdin
-
-   my_stdin = freopen(NULL, "rb", stdin);
-
-   if (my_stdin == nullptr)
-   {
-      cpd.error_count++;
-      usage_error();
-      return(EX_IOERR);
-   }
 #endif
 
    while (!feof(stdin))
@@ -2067,6 +2098,12 @@ void uncrustify_file(const file_mem &fm, FILE *pfout,
             newlines_chunk_pos(CT_ARITH, options::pos_arith());
             newlines_chunk_pos(CT_CARET, options::pos_arith());
          }
+         log_rule_B("pos_shift");
+
+         if (options::pos_shift() != TP_IGNORE)
+         {
+            newlines_chunk_pos(CT_SHIFT, options::pos_shift());
+         }
          newlines_class_colon_pos(CT_CLASS_COLON);
          newlines_class_colon_pos(CT_CONSTR_COLON);
 
@@ -2167,6 +2204,7 @@ void uncrustify_file(const file_mem &fm, FILE *pfout,
          {
             LOG_FMT(LNEWLINE, "%s(%d): Code_width loop start: %d\n",
                     __func__, __LINE__, cpd.changes);
+            log_rule_B("debug_max_number_of_loops");
 
             if (options::debug_max_number_of_loops() > 0)
             {
@@ -2219,7 +2257,14 @@ void uncrustify_file(const file_mem &fm, FILE *pfout,
 
       if (p_file != nullptr)
       {
-         output_parsed(p_file);
+         if (ends_with(parsed_file, ".csv", false))
+         {
+            output_parsed_csv(p_file);
+         }
+         else
+         {
+            output_parsed(p_file);
+         }
 
          if (p_file != stdout)
          {
@@ -2266,11 +2311,9 @@ void uncrustify_end()
    cpd.unc_off     = false;
    cpd.al_cnt      = 0;
    cpd.did_newline = true;
-   cpd.frames.clear();
-   cpd.pp_level   = 0;
-   cpd.changes    = 0;
-   cpd.in_preproc = CT_NONE;
-   cpd.consumed   = false;
+   cpd.pp_level    = 0;
+   cpd.changes     = 0;
+   cpd.in_preproc  = CT_NONE;
    memset(cpd.le_counts, 0, sizeof(cpd.le_counts));
    cpd.preproc_ncnl_count                     = 0;
    cpd.ifdef_over_whole_file                  = 0;
