@@ -12,8 +12,9 @@ void hurz(murks)
    }
 #ifdef SCHNIEPEL
    else if (murks = 6)         // This comment belongs to (murks = 6)
-   {                           // I had to write more comment than one line
+                               // I had to write more comment than one line
                                // so I inserted some comment only blocks
+   {
       schniepel();
    }
 #endif // SCHNIEPEL
