@@ -56,3 +56,21 @@ class I
 };
 
 void bar4();
+/* multiline test comment
+   before class */
+template<typename ... Args>
+// test comment between template specification and associated class
+class H
+{
+    // nested class
+template<typename ...>
+friend class I;
+friend class J;
+    // nested class K
+template<typename T>
+class K
+{
+        // double-nested class L
+class L { };
+};
+};
